# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .boundary import Boundary as Boundary_7fe2098c
    from .line_break_hyphenation_options import LineBreakHyphenationOptions as LineBreakHyphenationOptions_7d3b1128
    from .line_break_results import LineBreakResults as LineBreakResults_d8200ca7
    from .line_break_user_options import LineBreakUserOptions as LineBreakUserOptions_e440e40
    from ..lang.locale import Locale as Locale_70d308fa

class XBreakIterator(XInterface_8f010a43):
    """
    contains the base routines for iteration in Unicode string.
    
    Iterates over characters, words, sentences and line breaks.
    
    Assumption: StartPos is inclusive and EndPos is exclusive.

    See Also:
        `API XBreakIterator <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XBreakIterator.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.XBreakIterator'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.i18n.XBreakIterator'

    @abstractmethod
    def beginOfCharBlock(self, aText: str, nStartPos: int, aLocale: Locale_70d308fa, nCharType: int) -> int:
        """
        Traverses in Text from nStartPos to the beginning of the specified character type.
        """
        ...
    @abstractmethod
    def beginOfScript(self, aText: str, nStartPos: int, nScriptType: int) -> int:
        """
        Traverses in Text from nStartPos to the beginning of the specified script type.
        """
        ...
    @abstractmethod
    def beginOfSentence(self, aText: str, nStartPos: int, aLocale: Locale_70d308fa) -> int:
        """
        Traverses in Text from nStartPos to the start of a sentence.
        """
        ...
    @abstractmethod
    def endOfCharBlock(self, aText: str, nStartPos: int, aLocale: Locale_70d308fa, nCharType: int) -> int:
        """
        Traverses in Text from nStartPos to the end of the specified character type.
        """
        ...
    @abstractmethod
    def endOfScript(self, aText: str, nStartPos: int, nScriptType: int) -> int:
        """
        Traverses in Text from nStartPos to the end of the specified script type.
        """
        ...
    @abstractmethod
    def endOfSentence(self, aText: str, nStartPos: int, aLocale: Locale_70d308fa) -> int:
        """
        Traverses in Text from nStartPos to the end of a sentence.
        """
        ...
    @abstractmethod
    def getLineBreak(self, aText: str, nStartPos: int, aLocale: Locale_70d308fa, nMinBreakPos: int, aHyphOptions: LineBreakHyphenationOptions_7d3b1128, aUserOptions: LineBreakUserOptions_e440e40) -> LineBreakResults_d8200ca7:
        """
        Calculate the line break position in the Text from the specified nStartPos.
        """
        ...
    @abstractmethod
    def getScriptType(self, aText: str, nPos: int) -> int:
        """
        Get the script type of the character at position nPos.
        """
        ...
    @abstractmethod
    def getWordBoundary(self, aText: str, nPos: int, aLocale: Locale_70d308fa, nWordType: int, bPreferForward: bool) -> Boundary_7fe2098c:
        """
        Identifies StartPos and EndPos of current word.
        
        If nPos is the boundary of a word, it is StartPos of one word and EndPos of previous word. In this situation, the outcome of the algorithm can be indeterminate. In this situation the bPreferForward flag is used. If bPreferForward == FALSE, nPos is considered to be the end of the word and we look backwards for beginning of word, otherwise nPos is considered to be the start of the next word and we look forwards for the end of the word.
        """
        ...
    @abstractmethod
    def getWordType(self, aText: str, nPos: int, aLocale: Locale_70d308fa) -> int:
        """
        This method is mis-defined, since WordType is not an attribute of a word, but a way to break words, like excluding or including tail spaces for spell checker or cursor traveling. It returns 0 always.
        """
        ...
    @abstractmethod
    def isBeginWord(self, aText: str, nPos: int, aLocale: Locale_70d308fa, nWordType: int) -> bool:
        """
        If a word starts at position nPos.
        
        It is possible that both of this method and following method isEndWord all return TRUE, since StartPos of a word is inclusive while EndPos of a word is exclusive.
        """
        ...
    @abstractmethod
    def isEndWord(self, aText: str, nPos: int, aLocale: Locale_70d308fa, nWordType: int) -> bool:
        """
        If a word ends at position nPos.
        """
        ...
    @abstractmethod
    def nextCharBlock(self, aText: str, nStartPos: int, aLocale: Locale_70d308fa, nCharType: int) -> int:
        """
        Traverses in Text from nStartPos to the next start of the specified character type.
        """
        ...
    @abstractmethod
    def nextCharacters(self, aText: str, nStartPos: int, aLocale: Locale_70d308fa, nCharacterIteratorMode: int, nCount: int, nDone: int) -> int:
        """
        Traverses specified number of characters/cells in Text from nStartPos forwards.
        
        CharacterIteratorMode can be cell based or character based. A cell is made of more than one character.

        * ``nDone`` is an out direction argument.
        """
        ...
    @abstractmethod
    def nextScript(self, aText: str, nStartPos: int, nScriptType: int) -> int:
        """
        Traverses in Text from nStartPos to the next start of the specified script type.
        """
        ...
    @abstractmethod
    def nextWord(self, aText: str, nStartPos: int, aLocale: Locale_70d308fa, nWordType: int) -> Boundary_7fe2098c:
        """
        Traverses one word in Text from nStartPos forwards.
        """
        ...
    @abstractmethod
    def previousCharBlock(self, aText: str, nStartPos: int, aLocale: Locale_70d308fa, nCharType: int) -> int:
        """
        Traverses in Text from nStartPos to the previous start of the specified character type.
        """
        ...
    @abstractmethod
    def previousCharacters(self, aText: str, nStartPos: int, aLocale: Locale_70d308fa, nCharacterIteratorMode: int, nCount: int, nDone: int) -> int:
        """
        Traverses specified number of characters/cells in Text from nStartPos backwards.
        
        CharacterIteratorMode can be cell based or character based. A cell is made of more than one character.

        * ``nDone`` is an out direction argument.
        """
        ...
    @abstractmethod
    def previousScript(self, aText: str, nStartPos: int, nScriptType: int) -> int:
        """
        Traverses in Text from nStartPos to the previous start of the specified script type.
        """
        ...
    @abstractmethod
    def previousWord(self, aText: str, nStartPos: int, aLocale: Locale_70d308fa, nWordType: int) -> Boundary_7fe2098c:
        """
        Traverses one word in Text from nStartPos backwards.
        
        If the previous character is a space character and nWordType indicates spaces should be skipped, and if the first non-space character is an Asian character, then, since Asian word break needs language specific wordbreak dictionaries, the method will return -1 in Boundary.endPos() and the position after the Asian character (i.e. the space character) in Boundary.startPos(). The caller then has to call this method again with a correct aLocale referring to the Asian character, which is then the previous character of the space character where nStartPos points to.
        
        Note that the OpenOffice.org 1.0 / StarOffice 6.0 / StarSuite 6.0 i18n framework doesn't behave like this and mixed Western/CJK text may lead to wrong word iteration. This is fixed in later versions.
        """
        ...

__all__ = ['XBreakIterator']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import warnings
warnings.filterwarnings('module')
warnings.warn('The csslo namespace is deprecated. Use lo instead.', DeprecationWarning, stacklevel=2)
from ....lo.awt.tab.tab_page_activated_event import TabPageActivatedEvent as TabPageActivatedEvent
from ....lo.awt.tab.uno_control_tab_page import UnoControlTabPage as UnoControlTabPage
from ....lo.awt.tab.uno_control_tab_page_container import UnoControlTabPageContainer as UnoControlTabPageContainer
from ....lo.awt.tab.uno_control_tab_page_container_model import UnoControlTabPageContainerModel as UnoControlTabPageContainerModel
from ....lo.awt.tab.uno_control_tab_page_model import UnoControlTabPageModel as UnoControlTabPageModel
from ....lo.awt.tab.x_tab_page import XTabPage as XTabPage
from ....lo.awt.tab.x_tab_page_container import XTabPageContainer as XTabPageContainer
from ....lo.awt.tab.x_tab_page_container_listener import XTabPageContainerListener as XTabPageContainerListener
from ....lo.awt.tab.x_tab_page_container_model import XTabPageContainerModel as XTabPageContainerModel
from ....lo.awt.tab.x_tab_page_model import XTabPageModel as XTabPageModel



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.text
from __future__ import annotations
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .text_content import TextContent as TextContent_a6810b4d
from .x_text_field import XTextField as XTextField_9a630aae

class TextField(TextContent_a6810b4d, XPropertySet_bc180bfa, XTextField_9a630aae):
    """
    Service Class

    A TextField is a TextContent which fades its textual representation into the text range to which it is anchored.
    
    **since**
    
        OOo 2.0.1

    See Also:
        `API TextField <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextField.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.text'
    __ooo_full_ns__: str = 'com.sun.star.text.TextField'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def IsFieldDisplayed(self) -> bool:
        """
        specifies if the text field is actually displayed.
        
        Not all available text fields are actually displayed even when they are used. For example hidden fields or fields in hidden text are used in the document but get not displayed.
        
        **since**
        
            OOo 2.0.1
        """
        ...

    @abstractproperty
    def IsFieldUsed(self) -> bool:
        """
        specifies if the text field is actually used in the document.
        
        Not all available text fields are used, for example fields that are part of unused styles.
        
        **since**
        
            OOo 2.0.1
        """
        ...

    @abstractproperty
    def Title(self) -> str:
        """
        Contains short title for the field, used to for tooltip purposes if it's non-empty.
        
        **since**
        
            LibreOffice 7.4
        """
        ...


__all__ = ['TextField']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.style
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..lang.locale import Locale as Locale_70d308fa
    from com.sun.star.awt.FontSlant import FontSlantProto  # type: ignore

class CharacterPropertiesAsian(ABC):
    """
    Service Class

    This is a set of properties to describe the style of characters in Asian texts.

    See Also:
        `API CharacterPropertiesAsian <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1style_1_1CharacterPropertiesAsian.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.style'
    __ooo_full_ns__: str = 'com.sun.star.style.CharacterPropertiesAsian'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CharFontCharSetAsian(self) -> int:
        """
        This property contains the text encoding of the font as specified in com.sun.star.awt.CharSet.
        """
        ...

    @abstractproperty
    def CharFontFamilyAsian(self) -> int:
        """
        This property contains font family as specified in com.sun.star.awt.FontFamily .
        """
        ...

    @abstractproperty
    def CharFontNameAsian(self) -> str:
        """
        This property specifies the name of the font style.
        
        It may contain more than one name separated by comma.
        """
        ...

    @abstractproperty
    def CharFontPitchAsian(self) -> int:
        """
        This property contains the font pitch as specified in com.sun.star.awt.FontPitch.
        """
        ...

    @abstractproperty
    def CharFontStyleNameAsian(self) -> str:
        """
        This property contains the name of the font style.
        
        This property may be empty.
        """
        ...

    @abstractproperty
    def CharHeightAsian(self) -> float:
        """
        This value contains the height of the characters in point.
        """
        ...

    @abstractproperty
    def CharLocaleAsian(self) -> Locale_70d308fa:
        """
        contains the value of the locale.
        """
        ...

    @abstractproperty
    def CharPostureAsian(self) -> FontSlantProto:
        """
        This property contains the value of the posture of the document.
        """
        ...

    @abstractproperty
    def CharWeightAsian(self) -> float:
        """
        This property contains the value of the font weight.
        """
        ...


__all__ = ['CharacterPropertiesAsian']


# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing.framework
from __future__ import annotations
import typing
from abc import abstractmethod, ABC
if typing.TYPE_CHECKING:
    from .x_configuration_change_request import XConfigurationChangeRequest as XConfigurationChangeRequest_96e716cf

class XConfigurationControllerRequestQueue(ABC):
    """
    The request queue of the configuration controller handles requests for changes to the current configuration.
    
    This interface allows callers to add requests to the back of the queue and to determine whether the queue is empty. Using this interface should normally not be necessary for anyone else than the XConfigurationController. It may be removed in the future.

    See Also:
        `API XConfigurationControllerRequestQueue <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XConfigurationControllerRequestQueue.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing.framework'
    __ooo_full_ns__: str = 'com.sun.star.drawing.framework.XConfigurationControllerRequestQueue'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.framework.XConfigurationControllerRequestQueue'

    @abstractmethod
    def hasPendingRequests(self) -> bool:
        """
        Return whether there are pending requests for configuration changes.
        """
        ...
    @abstractmethod
    def postChangeRequest(self, xRequest: XConfigurationChangeRequest_96e716cf) -> None:
        """
        Add a request for a configuration change to the request queue.
        
        This method should not be called from outside the drawing framework. Other sub controllers of the drawing framework are typical callers. They can add change requests that can not be made with the requestResourceActivation() and requestResourceDeactivation() methods.
        """
        ...

__all__ = ['XConfigurationControllerRequestQueue']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..geometry.affine_matrix2_d import AffineMatrix2D as AffineMatrix2D_ff040da8
    from ..geometry.real_point2_d import RealPoint2D as RealPoint2D_d6e70c78
    from ..geometry.real_rectangle2_d import RealRectangle2D as RealRectangle2D_d9b0e03
    from .font_metrics import FontMetrics as FontMetrics_e4540d34
    from .render_state import RenderState as RenderState_e4490d27
    from .string_context import StringContext as StringContext_d50e22
    from .view_state import ViewState as ViewState_cab30c62
    from .x_bitmap import XBitmap as XBitmap_b1b70b7b
    from .x_canvas import XCanvas as XCanvas_b19b0b7a
    from .x_canvas_font import XCanvasFont as XCanvasFont_e3380d11
    from .x_graphic_device import XGraphicDevice as XGraphicDevice_ca80e2c
    from .x_poly_polygon2_d import XPolyPolygon2D as XPolyPolygon2D_e1b0e20
    from ..util.color import Color as Color_68e908c5

class XSimpleCanvas(XInterface_8f010a43):
    """
    Provides the basic graphical output operations for a canvas.
    
    This interface is a simplified version of the XCanvas interface. It holds explicit state, i.e. the pen and fill color, the current transformation, clip and font are persistently remembered.
    
    In contrast to the XCanvas interface, XSimpleCanvas does not distinguish between stroke and fill operations; instead, switching between stroke and fill (or taking both) works by setting appropriate pen and fill colors.

    See Also:
        `API XSimpleCanvas <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XSimpleCanvas.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.XSimpleCanvas'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.rendering.XSimpleCanvas'

    @abstractmethod
    def drawBitmap(self, xBitmap: XBitmap_b1b70b7b, aLeftTop: RealPoint2D_d6e70c78) -> None:
        """
        Draws the bitmap on the canvas.
        """
        ...
    @abstractmethod
    def drawLine(self, aStartPoint: RealPoint2D_d6e70c78, aEndPoint: RealPoint2D_d6e70c78) -> None:
        """
        Draws a line on the canvas.
        """
        ...
    @abstractmethod
    def drawPixel(self, aPoint: RealPoint2D_d6e70c78) -> None:
        """
        Sets a single pixel on the canvas.
        """
        ...
    @abstractmethod
    def drawPolyPolygon(self, xPolyPolygon: XPolyPolygon2D_e1b0e20) -> None:
        """
        Draws a poly-polygon on the canvas.
        """
        ...
    @abstractmethod
    def drawRect(self, aRect: RealRectangle2D_d9b0e03) -> None:
        """
        Draws a rectangle on the canvas.
        """
        ...
    @abstractmethod
    def drawText(self, aText: StringContext_d50e22, aOutPos: RealPoint2D_d6e70c78, nTextDirection: int) -> None:
        """
        Draws text on the canvas.
        """
        ...
    @abstractmethod
    def getCanvas(self) -> XCanvas_b19b0b7a:
        """
        Query the underlying XCanvas.
        """
        ...
    @abstractmethod
    def getCurrentClipRect(self) -> RealRectangle2D_d9b0e03:
        """
        Retrieve current clip rect.
        """
        ...
    @abstractmethod
    def getCurrentFillColor(self) -> Color_68e908c5:
        """
        Retrieve color currently used for fills.
        """
        ...
    @abstractmethod
    def getCurrentFont(self) -> XCanvasFont_e3380d11:
        """
        Retrieve currently selected font.
        """
        ...
    @abstractmethod
    def getCurrentPenColor(self) -> Color_68e908c5:
        """
        Retrieve color currently used for lines.
        """
        ...
    @abstractmethod
    def getCurrentRenderState(self, bUseFillColor: bool) -> RenderState_e4490d27:
        """
        Retrieve render state.
        """
        ...
    @abstractmethod
    def getCurrentTransformation(self) -> AffineMatrix2D_ff040da8:
        """
        Retrieve current transformation matrix.
        """
        ...
    @abstractmethod
    def getCurrentViewState(self) -> ViewState_cab30c62:
        """
        Retrieve view state.
        """
        ...
    @abstractmethod
    def getDevice(self) -> XGraphicDevice_ca80e2c:
        """
        Request the associated graphic device for this canvas.
        
        A graphic device provides methods specific to the underlying output device capabilities, which are common for all canvases rendering to such a device. This includes device resolution, color space, or bitmap formats.
        """
        ...
    @abstractmethod
    def getFontMetrics(self) -> FontMetrics_e4540d34:
        """
        Request the font metrics of the current font.
        """
        ...
    @abstractmethod
    def selectFont(self, sFontName: str, size: float, bold: bool, italic: bool) -> None:
        """
        Select a font.
        
        This method selects the specified font (or a close substitute) as the current font for text output.
        """
        ...
    @abstractmethod
    def setFillColor(self, nsRgbaColor: Color_68e908c5) -> None:
        """
        Sets the fill color.
        
        To disable filling, simply set this color to something with zero alpha (i.e. fully transparent).
        """
        ...
    @abstractmethod
    def setPenColor(self, nsRgbaColor: Color_68e908c5) -> None:
        """
        Sets the color used by line and text operations.
        
        To disable stroking, simply set this color to something with zero alpha (i.e. fully transparent).
        """
        ...
    @abstractmethod
    def setRectClip(self, aRect: RealRectangle2D_d9b0e03) -> None:
        """
        Sets the clip to the specified rectangle.
        """
        ...
    @abstractmethod
    def setTransformation(self, aTransform: AffineMatrix2D_ff040da8) -> None:
        """
        Set the current transform matrix.
        """
        ...

__all__ = ['XSimpleCanvas']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form


class FormComponentType(object):
    """
    Const Class

    These constants specify the class types used to identify a component.

    See Also:
        `API FormComponentType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1form_1_1FormComponentType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.FormComponentType'
    __ooo_type_name__: str = 'const'

    CONTROL = 1
    """
    This generic identifier is for controls which cannot be identified by another specific identifier.
    """
    COMMANDBUTTON = 2
    """
    specifies a control that is used to begin, interrupt, or end a process.
    """
    RADIOBUTTON = 3
    """
    specifies a control that acts like a radio button.
    
    Grouped together, such radio buttons present a set of two or more mutually exclusive choices to the user.
    """
    IMAGEBUTTON = 4
    """
    specifies a control that displays an image that responds to mouse clicks.
    """
    CHECKBOX = 5
    """
    specifies a control that is used to check or uncheck to turn an option on or off.
    """
    LISTBOX = 6
    """
    specifies a control that displays a list from which the user can select one or more items.
    """
    COMBOBOX = 7
    """
    specifies a control that is used when a list box combined with a static text control or an edit control is needed.
    """
    GROUPBOX = 8
    """
    specifies a control that displays a frame around a group of controls with or without a caption.
    """
    TEXTFIELD = 9
    """
    specifies a control that is a text component that allows for the editing of a single line of text.
    """
    FIXEDTEXT = 10
    """
    specifies a control to display a fixed text, usually used to label other controls.
    """
    GRIDCONTROL = 11
    """
    is a table like control to display database data.
    """
    FILECONTROL = 12
    """
    specifies a control which can be used to enter text, extended by an (user-startable) file dialog to browse for files.
    """
    HIDDENCONTROL = 13
    """
    specifies a control that should not be visible.
    """
    IMAGECONTROL = 14
    """
    specifies a control to display an image.
    """
    DATEFIELD = 15
    """
    specifies a control to display and edit a date value.
    """
    TIMEFIELD = 16
    """
    specifies a control to display and edit a time value.
    """
    NUMERICFIELD = 17
    """
    specifies a field to display and edit a numeric value.
    """
    CURRENCYFIELD = 18
    """
    specifies a field to display and edit a currency value.
    """
    PATTERNFIELD = 19
    """
    specifies a control to display and edit a string according to a pattern.
    """
    SCROLLBAR = 20
    """
    specifies a control to display and edit, in the form of a scrollbar, a value from a continuous value range
    """
    SPINBUTTON = 21
    """
    specifies a control to edit, in the form of a spin field, a value from a continuous range of values
    """
    NAVIGATIONBAR = 22
    """
    specifies a control which provides controller functionality for the com.sun.star.form.component.DataForm it belongs to, such as functionality to navigate or filter this form.
    """

__all__ = ['FormComponentType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from __future__ import annotations
import typing
from abc import abstractproperty
from .uno_control_model import UnoControlModel as UnoControlModel_c8ce0c58
if typing.TYPE_CHECKING:
    from ..util.color import Color as Color_68e908c5

class UnoControlSpinButtonModel(UnoControlModel_c8ce0c58):
    """
    Service Class

    specifies the standard model of a UnoControlSpinButton.
    
    A spin button is a control which has a numeric value associated with it, and allows to change this value using two spin buttons.
    
    A spin button is similar to a scroll bar, but it usually has no (own) visual representation of the associated value, but is used to propagate its value to other controls.
    
    **since**
    
        OOo 2.0

    See Also:
        `API UnoControlSpinButtonModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1UnoControlSpinButtonModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.UnoControlSpinButtonModel'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def BackgroundColor(self) -> Color_68e908c5:
        """
        specifies the RGB color to be used for the control
        """
        ...

    @abstractproperty
    def Border(self) -> int:
        """
        specifies the border style of the control.
        """
        ...

    @abstractproperty
    def BorderColor(self) -> int:
        """
        specifies the color of the border, if present
        
        Not every border style (see Border) may support coloring. For instance, usually a border with 3D effect will ignore the BorderColor setting.
        
        **since**
        
            OOo 2.0
        """
        ...

    @abstractproperty
    def Enabled(self) -> bool:
        """
        determines whether the control is enabled or disabled.
        """
        ...

    @abstractproperty
    def HelpText(self) -> str:
        """
        specifies the help text of the control.
        """
        ...

    @abstractproperty
    def HelpURL(self) -> str:
        """
        specifies the help URL of the control.
        """
        ...

    @abstractproperty
    def MouseWheelBehavior(self) -> int:
        """
        defines how the mouse wheel can be used to scroll through the control's content.
        
        Usually, the mouse wheel spins the numeric value displayed in the control. Using this property, and one of the MouseWheelBehavior constants, you can control under which circumstances this is possible.
        """
        ...

    @abstractproperty
    def Orientation(self) -> int:
        """
        specifies the ScrollBarOrientation of the control.
        """
        ...

    @abstractproperty
    def Printable(self) -> bool:
        """
        specifies whether the control will be printed with the document.
        """
        ...

    @abstractproperty
    def Repeat(self) -> bool:
        """
        specifies whether the mouse should show repeating behavior, i.e.
        
        repeatedly trigger an action when keeping pressed.
        """
        ...

    @abstractproperty
    def RepeatDelay(self) -> int:
        """
        specifies the mouse repeat delay, in milliseconds.
        
        When the user presses a mouse in a control area where this triggers an action (such as spinning the value), then usual control implementations allow to repeatedly trigger this action, without the need to release the mouse button and to press it again. The delay between two such triggers is specified with this property.
        """
        ...

    @abstractproperty
    def SpinIncrement(self) -> int:
        """
        specifies the increment by which the value is changed when using operating the spin button.
        """
        ...

    @abstractproperty
    def SpinValue(self) -> int:
        """
        specifies the current value of the control.
        """
        ...

    @abstractproperty
    def SpinValueMax(self) -> int:
        """
        specifies the maximum value of the control.
        """
        ...

    @abstractproperty
    def SpinValueMin(self) -> int:
        """
        specifies the minimum value of the control.
        """
        ...

    @abstractproperty
    def SymbolColor(self) -> Color_68e908c5:
        """
        specifies the RGB color to be used when painting symbols which are part of the control's appearance, such as the arrow buttons.
        """
        ...


__all__ = ['UnoControlSpinButtonModel']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart
from __future__ import annotations
from abc import abstractproperty
from .x3_d_default_setter import X3DDefaultSetter as X3DDefaultSetter_e9630d25
from .x3_d_display import X3DDisplay as X3DDisplay_a1650abf

class Dim3DDiagram(X3DDefaultSetter_e9630d25, X3DDisplay_a1650abf):
    """
    Service Class

    is a service for diagrams that support the capability to render themselves as three-dimensional diagrams as well as two-dimensional ones.

    See Also:
        `API Dim3DDiagram <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart_1_1Dim3DDiagram.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart'
    __ooo_full_ns__: str = 'com.sun.star.chart.Dim3DDiagram'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Dim3D(self) -> bool:
        """
        If set to TRUE, the chart becomes a three-dimensional chart.
        
        Otherwise it is two-dimensional.
        """
        ...

    @abstractproperty
    def Perspective(self) -> int:
        """
        Perspective of 3D charts ( [0,100] ).
        """
        ...

    @abstractproperty
    def RotationHorizontal(self) -> int:
        """
        Horizontal rotation of 3D charts in degrees ( ]-180,180] ).
        """
        ...

    @abstractproperty
    def RotationVertical(self) -> int:
        """
        Vertical rotation of 3D charts in degrees ( ]-180,180] ).
        """
        ...


__all__ = ['Dim3DDiagram']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.mozilla
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from com.sun.star.mozilla.MozillaProductType import MozillaProductTypeProto  # type: ignore
    from com.sun.star.mozilla.MozillaProductType import MozillaProductTypeProto  # type: ignore
    from com.sun.star.mozilla.MozillaProductType import MozillaProductTypeProto  # type: ignore
    from com.sun.star.mozilla.MozillaProductType import MozillaProductTypeProto  # type: ignore
    from com.sun.star.mozilla.MozillaProductType import MozillaProductTypeProto  # type: ignore
    from com.sun.star.mozilla.MozillaProductType import MozillaProductTypeProto  # type: ignore

class XProfileDiscover(XInterface_8f010a43):
    """
    is the interface used to list and get information for Mozilla/Thunderbird profiles

    See Also:
        `API XProfileDiscover <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1mozilla_1_1XProfileDiscover.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.mozilla'
    __ooo_full_ns__: str = 'com.sun.star.mozilla.XProfileDiscover'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.mozilla.XProfileDiscover'

    @abstractmethod
    def getDefaultProfile(self, product: MozillaProductTypeProto) -> str:
        """
        attempts to get the default profile name for the given product.
        """
        ...
    @abstractmethod
    def getProfileCount(self, product: MozillaProductTypeProto) -> int:
        """
        attempts to get the profiles count.
        """
        ...
    @abstractmethod
    def getProfileExists(self, product: MozillaProductTypeProto, profileName: str) -> bool:
        """
        return true if the given profile exists
        """
        ...
    @abstractmethod
    def getProfileList(self, product: MozillaProductTypeProto, list: typing.Tuple[str, ...]) -> int:
        """
        attempts to get the profile list for the given product.

        * ``list`` is an out direction argument.
        """
        ...
    @abstractmethod
    def getProfilePath(self, product: MozillaProductTypeProto, profileName: str) -> str:
        """
        attempts to get the full path for the given profile.
        """
        ...
    @abstractmethod
    def isProfileLocked(self, product: MozillaProductTypeProto, profileName: str) -> bool:
        """
        attempts to get whether profile is locked by other applications.
        """
        ...

__all__ = ['XProfileDiscover']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XTypeDetection(XInterface_8f010a43):
    """
    support \"flat\" and \"deep\" type detection of a given document
    
    A \"flat\" detection means specifying the document format by using the URL and some configuration data only. That will perform but produce may invalid results if e.g., the extension of the document is wrong. A \"deep\" detection means looking into the document stream to be right which format it supports. Of course that includes a \"flat\" detection before. The combination of both ones should produce stable results every time.

    See Also:
        `API XTypeDetection <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XTypeDetection.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.XTypeDetection'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.document.XTypeDetection'

    @abstractmethod
    def queryTypeByDescriptor(self, Descriptor: object, AllowDeep: bool) -> str:
        """
        make a \"deep\" detection or optional a \"flat\" detection by using a MediaDescriptor
        
        Instead of XTypeDetection.queryTypeByURL() this function use a MediaDescriptor to specify the document for detection. Such descriptor hold different information about the document. He will be passed to any part of made detection process and every part can change it to actualize it. The property MediaDescriptor.URL should be set on this descriptor as minimum. It specifies the location of the document. If this parameter is missing another one is required: MediaDescriptor.InputStream. This can be useful to prevent operation against multiple opening of the stream and perform the operation. If this stream isn't already included the detection will open it (if allowed!) and add it to the descriptor so it will be available for all following parts. A combination of both parameters can be useful to perform the operation and make results more stable; but only one of them is required. Of course its possible to specify more document properties (e.g. MediaDescriptor.ReadOnly). As an additional feature it's possible to suppress \"deep\" detection by using argument AllowDeep.
        """
        ...
    @abstractmethod
    def queryTypeByURL(self, URL: str) -> str:
        """
        make a \"flat\" detection by using the URL of the document
        
        It use given URL in combination with the internal configuration of well known types only to specify the format of given document.
        """
        ...

__all__ = ['XTypeDetection']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.view
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_control_access import XControlAccess as XControlAccess_c89d0c4e
if typing.TYPE_CHECKING:
    from ..form.x_form import XForm as XForm_684408a8
    from ..form.runtime.x_form_controller import XFormController as XFormController_4a570ffe

class XFormLayerAccess(XControlAccess_c89d0c4e):
    """
    provides access to the form layer elements in a view
    
    **since**
    
        OOo 2.3

    See Also:
        `API XFormLayerAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1view_1_1XFormLayerAccess.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.view'
    __ooo_full_ns__: str = 'com.sun.star.view.XFormLayerAccess'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.view.XFormLayerAccess'

    @abstractmethod
    def getFormController(self, Form: XForm_684408a8) -> XFormController_4a570ffe:
        """
        returns the com.sun.star.form.FormController instance which operates on a given form.
        
        A form controller is a component which controls the user interaction with the form layer, as long as the form is not in design mode.
        """
        ...
    @abstractmethod
    def isFormDesignMode(self) -> bool:
        """
        determines whether the view's form layer is currently in design or alive mode
        
        Note: This is a convenience method. In the user interface, the design mode is coupled with the .uno:SwitchControlDesignMode feature (see com.sun.star.frame.XDispatchProvider), and asking for the current mode is the same as asking for the state of this feature.
        """
        ...
    @abstractmethod
    def setFormDesignMode(self, DesignMode: bool) -> None:
        """
        determines whether the view's form layer is currently in design or alive mode
        
        Note: This is a convenience method. In the user interface, the design mode is coupled with the .uno:SwitchControlDesignMode feature (see com.sun.star.frame.XDispatchProvider), and changing the current mode is the same as dispatching this feature URL.
        """
        ...

__all__ = ['XFormLayerAccess']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2
from __future__ import annotations
from .x_number_text import XNumberText as XNumberText_feeb0ddb

class NumberText(XNumberText_feeb0ddb):
    """
    Service Class

    provides converter to spell out numbers and money amounts
    
    An implementation of this service will receive text and has to spell out as cardinal, ordinal, ordinal indicator or money amounts.
    
    An implementation of this service is not limited to number to number conversion at all. It might also support other linguistic functions of a given language, for example, spelling out years, gender and formal variants or complex affixation of number names, or article selection.
    
    **since**
    
        LibreOffice 6.1

    See Also:
        `API NumberText <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1linguistic2_1_1NumberText.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.NumberText'
    __ooo_type_name__: str = 'service'


__all__ = ['NumberText']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.animations
import uno
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class AnimationFill(metaclass=UnoConstMeta, type_name="com.sun.star.animations.AnimationFill", name_space="com.sun.star.animations"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.animations.AnimationFill``"""
        pass

    class AnimationFillEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.animations.AnimationFill", name_space="com.sun.star.animations"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.animations.AnimationFill`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.animations import AnimationFill as AnimationFill
    else:
        # keep document generators happy
        from ...lo.animations.animation_fill import AnimationFill as AnimationFill

    class AnimationFillEnum(IntEnum):
        """
        Enum of Const Class AnimationFill

        This constants are used for the members fill() and fillDefault() of the an XTimeContainer.
        """
        DEFAULT = AnimationFill.DEFAULT
        """
        The fill behavior for the element is determined by the value of the XTiming.FillDefault attribute.
        
        This is the default value for the XTiming.Fill... If the application of fillDefault to an element would result in the element having a value of fill that is not allowed on that element, the element will instead have a fill value of AnimationFill.AUTO.
        """
        INHERIT = AnimationFill.INHERIT
        """
        Specifies that the value of this attribute (and of the fill behavior) are inherited from the XTiming.FillDefault value of the parent element.
        
        If there is no parent element, the value is AnimationFill.AUTO. This is the default value for the XTiming.FillDefault.
        """
        REMOVE = AnimationFill.REMOVE
        """
        Specifies that the element will not extend past the end of the last instance of the simple duration.
        """
        FREEZE = AnimationFill.FREEZE
        """
        Specifies that the element will extend past the end of the last instance of the simple duration by \"freezing\" the element state at that point.
        
        The parent time container of the element determines how long the element is frozen (as described immediately below).
        """
        HOLD = AnimationFill.HOLD
        """
        Setting this to \"hold\" has the same effect as setting to \"freeze\", except that the element is always frozen to extend to the end of the simple duration of the parent time container of the element (independent of the type of time container).
        
        For profiles that support a layered layout model (e.g., SMIL 2.0 Language Profile), held elements (elements with fill=\"hold\") will refresh their display area when a layer is added on top then later removed.
        """
        TRANSITION = AnimationFill.TRANSITION
        """
        Setting this to \"transition\" has the same effect as setting to \"freeze\", except that the element is removed at the end of the transition.
        
        This value is only allowed on elements with media directly associated with them. If specified on any other element (e.g. a time container element in the SMIL language profile), the attribute is ignored. See the SMIL Transitions module.
        """
        AUTO = AnimationFill.AUTO
        """
        The fill behavior for this element depends on whether the element specifies any of the attributes that define the simple or active duration:
        """

__all__ = ['AnimationFill', 'AnimationFillEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.chart2
from __future__ import annotations
import typing
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa

class LogicTargetModel(ABC):
    """
    Service Class

    The properties of this service correspond to the similar named attributes and subelements of the XML element chart2:increment in the chart2 file format.

    See Also:
        `API LogicTargetModel <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1chart2_1_1LogicTargetModel.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.chart2'
    __ooo_full_ns__: str = 'com.sun.star.chart2.LogicTargetModel'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def CoordinateSystems(self) -> typing.Tuple[XPropertySet_bc180bfa, ...]:
        """
        not BOUND nor CONSTRAINED in terms of Listener notifications, each element in the sequence must implement the service com.sun.star.chart2.CoordinateSystem
        """
        ...

    @abstractproperty
    def LogicTargetModels(self) -> typing.Tuple[XPropertySet_bc180bfa, ...]:
        """
        MAYBEVOID, not BOUND nor CONSTRAINED in terms of Listener notifications, each element in the sequence must implement the service com.sun.star.chart2.LogicTargetModel.
        """
        ...

    @abstractproperty
    def ID(self) -> str:
        """
        identifies an instance of this service within one chart document.
        """
        ...

    @abstractproperty
    def LegendID(self) -> str:
        """
        identifies an instance of the service com.sun.star.chart2.LegendModel within one chart document.
        
        that instance is used to automatically calculate missing properties
        """
        ...


__all__ = ['LogicTargetModel']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script
from __future__ import annotations
from ..lang.x_single_service_factory import XSingleServiceFactory as XSingleServiceFactory_27210f0d

class Invocation(XSingleServiceFactory_27210f0d):
    """
    Service Class

    factory service that allows construction of Invocation objects.
    
    Invoke createInstanceWithArguments() of XSingleServiceFactory to create an Invocation adapter for the passed object (Invoking createInstance() will fail).
    
    The adapter has to support com.sun.star.script.XInvocation. The adapter may also support com.sun.star.script.XInvocation2.

    See Also:
        `API Invocation <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1script_1_1Invocation.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script'
    __ooo_full_ns__: str = 'com.sun.star.script.Invocation'
    __ooo_type_name__: str = 'service'


__all__ = ['Invocation']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class ConditionOperator(Enum):
    """
    Enum Class


    See Also:
        `API ConditionOperator <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sheet.html#adab1b2b49825a75bed998dd77963eff9>`_
    """
    __ooo_ns__: str = "com.sun.star.sheet"
    __ooo_full_ns__: str = "com.sun.star.sheet.ConditionOperator"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.sheet.ConditionOperator"

    BETWEEN = "BETWEEN"
    """
    the value has to be between the two specified values.
    """
    EQUAL = "EQUAL"
    """
    value has to be equal to the specified value.
    
    The cell value is equal to the specified value.
    """
    FORMULA = "FORMULA"
    """
    the specified formula has to give a non-zero result.
    """
    GREATER = "GREATER"
    """
    the value has to be greater than the specified value.
    
    value has to be greater than the specified value.
    """
    GREATER_EQUAL = "GREATER_EQUAL"
    """
    the value has to be greater than or equal to the specified value.
    
    The cell value is greater or equal to the specified value.
    
    value has to be greater than or equal to the specified value.
    """
    LESS = "LESS"
    """
    the value has to be less than the specified value.
    
    value has to be less than the specified value.
    """
    LESS_EQUAL = "LESS_EQUAL"
    """
    the value has to be less than or equal to the specified value.
    
    The cell value is less or equal to the specified value.
    
    value has to be less than or equal to the specified value.
    """
    NONE = "NONE"
    """
    no cells are moved.
    
    sheet is not linked.
    
    new values are used without changes.
    
    nothing is calculated.
    
    nothing is imported.
    
    no condition is specified.
    """
    NOT_BETWEEN = "NOT_BETWEEN"
    """
    the value has to be outside of the two specified values.
    """
    NOT_EQUAL = "NOT_EQUAL"
    """
    the value must not be equal to the specified value.
    
    value must not be equal to the specified value.
    """

__all__ = ["ConditionOperator"]




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.awt
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
from .input_event import InputEvent as InputEvent_8f520a66
from ..uno.x_interface import XInterface as XInterface_8f010a43
import typing


class MouseEvent(InputEvent_8f520a66):
    """
    Struct Class

    specifies an event from the mouse.
    
    This event is also used for pop-up menu requests on objects. See PopupTrigger for details.

    See Also:
        `API MouseEvent <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1awt_1_1MouseEvent.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.MouseEvent'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.awt.MouseEvent'
    """Literal Constant ``com.sun.star.awt.MouseEvent``"""

    def __init__(self, Source: typing.Optional[XInterface_8f010a43] = None, Modifiers: typing.Optional[int] = 0, Buttons: typing.Optional[int] = 0, X: typing.Optional[int] = 0, Y: typing.Optional[int] = 0, ClickCount: typing.Optional[int] = 0, PopupTrigger: typing.Optional[bool] = False) -> None:
        """
        Constructor

        Arguments:
            Source (XInterface, optional): Source value.
            Modifiers (int, optional): Modifiers value.
            Buttons (int, optional): Buttons value.
            X (int, optional): X value.
            Y (int, optional): Y value.
            ClickCount (int, optional): ClickCount value.
            PopupTrigger (bool, optional): PopupTrigger value.
        """

        if isinstance(Source, MouseEvent):
            oth: MouseEvent = Source
            self.Source = oth.Source
            self.Modifiers = oth.Modifiers
            self.Buttons = oth.Buttons
            self.X = oth.X
            self.Y = oth.Y
            self.ClickCount = oth.ClickCount
            self.PopupTrigger = oth.PopupTrigger
            return

        kargs = {
            "Source": Source,
            "Modifiers": Modifiers,
            "Buttons": Buttons,
            "X": X,
            "Y": Y,
            "ClickCount": ClickCount,
            "PopupTrigger": PopupTrigger,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._buttons = kwargs["Buttons"]
        self._x = kwargs["X"]
        self._y = kwargs["Y"]
        self._click_count = kwargs["ClickCount"]
        self._popup_trigger = kwargs["PopupTrigger"]
        inst_keys = ('Buttons', 'X', 'Y', 'ClickCount', 'PopupTrigger')
        kargs = kwargs.copy()
        for key in inst_keys:
            del kargs[key]
        super()._init(**kargs)


    @property
    def Buttons(self) -> int:
        """
        contains the pressed mouse buttons.
        
        Zero ore more constants from the com.sun.star.awt.MouseButton group.
        """
        return self._buttons

    @Buttons.setter
    def Buttons(self, value: int) -> None:
        self._buttons = value

    @property
    def X(self) -> int:
        """
        contains the x coordinate location of the mouse.
        """
        return self._x

    @X.setter
    def X(self, value: int) -> None:
        self._x = value

    @property
    def Y(self) -> int:
        """
        contains the y coordinate location of the mouse.
        """
        return self._y

    @Y.setter
    def Y(self, value: int) -> None:
        self._y = value

    @property
    def ClickCount(self) -> int:
        """
        contains the number of mouse clicks associated with event.
        """
        return self._click_count

    @ClickCount.setter
    def ClickCount(self, value: int) -> None:
        self._click_count = value

    @property
    def PopupTrigger(self) -> bool:
        """
        specifies if this event is a pop-up menu trigger event.
        
        If this member is TRUE, the event describes a request for a pop-up menu, also known as context menu, on an object.
        
        In this case, X and Y describe the position where the request was issued. If those members are -1, then the request was issued using the keyboard, by pressing the operating-system dependent key combination for this purpose.
        """
        return self._popup_trigger

    @PopupTrigger.setter
    def PopupTrigger(self, value: bool) -> None:
        self._popup_trigger = value


__all__ = ['MouseEvent']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.binding
from __future__ import annotations
import typing
from abc import abstractmethod
from ...lang.x_event_listener import XEventListener as XEventListener_c7230c4a
if typing.TYPE_CHECKING:
    from .list_entry_event import ListEntryEvent as ListEntryEvent_37f10f75
    from ...lang.event_object import EventObject as EventObject_a3d70b03

class XListEntryListener(XEventListener_c7230c4a):
    """
    specifies a listener for changes in a string entry list

    See Also:
        `API XListEntryListener <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1binding_1_1XListEntryListener.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.binding'
    __ooo_full_ns__: str = 'com.sun.star.form.binding.XListEntryListener'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.form.binding.XListEntryListener'

    @abstractmethod
    def allEntriesChanged(self, Source: EventObject_a3d70b03) -> None:
        """
        notifies the listener that all entries of the list have changed.
        
        The listener should retrieve the complete new list by calling the XListEntrySource.getAllListEntries() method of the event source (which is denoted by com.sun.star.lang.EventObject.Source).
        """
        ...
    @abstractmethod
    def entryChanged(self, Source: ListEntryEvent_37f10f75) -> None:
        """
        notifies the listener that a single entry in the list has change
        """
        ...
    @abstractmethod
    def entryRangeInserted(self, Source: ListEntryEvent_37f10f75) -> None:
        """
        notifies the listener that a range of entries has been inserted into the list
        """
        ...
    @abstractmethod
    def entryRangeRemoved(self, Source: ListEntryEvent_37f10f75) -> None:
        """
        notifies the listener that a range of entries has been removed from the list
        """
        ...

__all__ = ['XListEntryListener']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form.runtime
from __future__ import annotations
import typing
from abc import abstractmethod, abstractproperty
from ...awt.x_tab_controller import XTabController as XTabController_bacd0be7
from ...container.x_child import XChild as XChild_a6390b07
from ...container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ...container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
from ..x_confirm_delete_broadcaster import XConfirmDeleteBroadcaster as XConfirmDeleteBroadcaster_6772109f
from ..x_database_parameter_broadcaster2 import XDatabaseParameterBroadcaster2 as XDatabaseParameterBroadcaster2_bee51266
from .x_filter_controller import XFilterController as XFilterController_6b5a10d0
from ...lang.x_component import XComponent as XComponent_98dc0ab5
from ...sdb.x_row_set_approve_broadcaster import XRowSetApproveBroadcaster as XRowSetApproveBroadcaster_56601044
from ...sdb.xsql_error_broadcaster import XSQLErrorBroadcaster as XSQLErrorBroadcaster_4d10dfd
from ...util.x_mode_selector import XModeSelector as XModeSelector_bbdc0be4
from ...util.x_modify_broadcaster import XModifyBroadcaster as XModifyBroadcaster_fd990df0
if typing.TYPE_CHECKING:
    from ...awt.x_control import XControl as XControl_7a9c098d
    from ..x_form_controller_listener import XFormControllerListener as XFormControllerListener_49ba1012
    from .x_form_controller_context import XFormControllerContext as XFormControllerContext_c54112e3
    from .x_form_operations import XFormOperations as XFormOperations_4a450ffe
    from ...task.x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51

class XFormController(XTabController_bacd0be7, XChild_a6390b07, XEnumerationAccess_4bac0ffc, XIndexAccess_f0910d6d, XConfirmDeleteBroadcaster_6772109f, XDatabaseParameterBroadcaster2_bee51266, XFilterController_6b5a10d0, XComponent_98dc0ab5, XRowSetApproveBroadcaster_56601044, XSQLErrorBroadcaster_4d10dfd, XModeSelector_bbdc0be4, XModifyBroadcaster_fd990df0):
    """
    specifies a component controlling the interaction between the user and form functionality.
    
    As soon as a form (containing controls) is to be presented to the user, there is a need for an instance controlling the user interaction.Such a FormController is responsible for dialog processing, like controlling the tab order and the grouping of controls.
    
    As a form may contain one or many subforms, a FormController may contain one or more other FormControllers, so the form model structure or hierarchy is reflected in the structure of FormControllers. That is, retrieving the parent of the model of a controller will give you the same object as retrieving the model of the parent of the controller. Similarly, retrieving the model of the nth child of a controller gives you the same object as retrieving the nth child of the model of the controller.
    
    A controller is called active if one of the controls it is responsible for has the focus, else inactive. To be notified whenever this activation state of a given controller changes, you can add listeners.
    
    This interface supersedes the com.sun.star.form.FormController.
    
    A FormController is responsible for a com.sun.star.awt.UnoControlContainer, and all controls therein.
    
    Furthermore, a form controller is responsible for preventing invalid user input. That is, if the form contains controls bound to a database, or to an external validator, then the form controller will check their current value when the current record is to be saved to the database.
    
    First, it will check whether any controls with an external validator exist. If so, those validators will be asked to validate the current control content. If this fails, the message provided by the validator is displayed to the user, the control is focused, and the update of the record is vetoed.
    
    Second, the controls are examined for NULL values. If a control is bound to a database field which is declared to be NOT NULL, no auto-increment field, but still NULL, then an error message is shown to the user saying that input is required, the respective control is focused, and the update of the record is vetoed.
    
    Note that you can present the second check - for database fields containing NULL values - on a per-form and a per-database basis.For the former, you need to add a boolean property FormsCheckRequiredFields to the form (aka the FormController's model), using its com.sun.star.beans.XPropertyContainer.addProperty() method, with a value of FALSE.For the latter, you need to set the respective property of the data source's Settings (also named FormsCheckRequiredFields) to FALSE.
    
    Alternatively, you can prevent the check on a per-control basis, using the DataAwareControlModel.InputRequired property of a single control model.
    
    If a control which the controller is responsible for supports the com.sun.star.frame.XDispatchProviderInterception interface, the controller registers a dispatch interceptor. Then, the control can try to delegate part of its functionality to the controller by querying the dispatch interceptor for it.
    
    Below, there's a list of URLs which have a defined meaning - if an implementation supports one of them, there must be a guaranteed semantics. However, concrete implementations may support an arbitrary sub or super set of these URLs.
    
    In general, all URLs start with the same prefix, namely .uno:FormController/. To this, a suffix is appended which describes the requested functionality.Example: The URL suffix for deleting the current record is deleteRecord, so the complete URL for requesting a dispatcher for this functionality is .uno:FormController/deleteRecord.
    
    Some URLs may require parameters. For this, the sequence of com.sun.star.beans.PropertyValues passed to the com.sun.star.frame.XDispatch.dispatch() call is used - every property value is used as one named parameter.
    
    For all URLs, interested parties can register as status listeners (com.sun.star.frame.XStatusListener) at the dispatchers, and be notified whenever the functionality associated with the URL becomes enabled or disabled.For instance, the URL with the suffix moveToFirst is associated with moving the form to the first record, and it will be disabled in case the form is already positioned on the first record.
    
    **since**
    
        OOo 3.3

    See Also:
        `API XFormController <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1form_1_1runtime_1_1XFormController.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form.runtime'
    __ooo_full_ns__: str = 'com.sun.star.form.runtime.XFormController'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.form.runtime.XFormController'

    @abstractmethod
    def addActivateListener(self, Listener: XFormControllerListener_49ba1012) -> None:
        """
        adds the specified listener to receive notifications whenever the activation state of the controller changes.
        """
        ...
    @abstractmethod
    def addChildController(self, ChildController: XFormController) -> None:
        """
        adds a controller to the list of child controllers

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def removeActivateListener(self, Listener: XFormControllerListener_49ba1012) -> None:
        """
        removes the specified listener from the list of components to receive notifications whenever the activation state of the controller changes.
        """
        ...
    @abstractproperty
    def Context(self) -> XFormControllerContext_c54112e3:
        """
        allows to delegate certain tasks to the context of the form controller
        """
        ...

    @abstractproperty
    def CurrentControl(self) -> XControl_7a9c098d:
        """
        provides access to the currently active control
        """
        ...

    @abstractproperty
    def FormOperations(self) -> XFormOperations_4a450ffe:
        """
        denotes the instance which is used to implement operations on the form which the controller works for.
        
        This instance can be used, for instance, to determine the current state of certain form features.
        """
        ...

    @abstractproperty
    def InteractionHandler(self) -> XInteractionHandler_bf80e51:
        """
        used (if not NULL) for user interactions triggered by the form controller.
        """
        ...


__all__ = ['XFormController']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..container.x_named import XNamed as XNamed_a6520b08
from .x_hierarchies_supplier import XHierarchiesSupplier as XHierarchiesSupplier_29a50f34
from ..util.x_cloneable import XCloneable as XCloneable_99d00aa3
if typing.TYPE_CHECKING:
    from .table_filter_field import TableFilterField as TableFilterField_ee760d53
    from com.sun.star.sheet.GeneralFunction import GeneralFunctionProto  # type: ignore
    from com.sun.star.sheet.DataPilotFieldOrientation import DataPilotFieldOrientationProto  # type: ignore

class DataPilotSourceDimension(XPropertySet_bc180bfa, XNamed_a6520b08, XHierarchiesSupplier_29a50f34, XCloneable_99d00aa3):
    """
    Service Class

    represents a dimension in a data pilot source.
    
    A dimension is equivalent to a column of a cell range in a spreadsheet used for a data pilot field.
    
    In more complex data sources, a dimension may contain several hierarchies, which consolidate items of a complex data type, called levels.
    
    Example: In a database, a column contains date values. This column will be a dimension of the data pilot source. One hierarchy may contain the 3 levels year, month, day. Another hierarchy may contain the 2 levels year and week number.
    
    **since**
    
        LibreOffice 5.3

    See Also:
        `API DataPilotSourceDimension <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1DataPilotSourceDimension.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.DataPilotSourceDimension'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def Filter(self) -> typing.Tuple[TableFilterField_ee760d53, ...]:
        """
        specifies which values are used.
        """
        ...

    @abstractproperty
    def Flags(self) -> int:
        """
        contains flags that control the usage of the dimension.
        """
        ...

    @abstractproperty
    def Function(self) -> GeneralFunctionProto:
        """
        specifies how data are aggregated.
        """
        ...

    @abstractproperty
    def Function2(self) -> int:
        """
        specifies how data are aggregated.
        
        **since**
        
            LibreOffice 5.3
        """
        ...

    @abstractproperty
    def IsDataLayoutDimension(self) -> bool:
        """
        contains TRUE if this is the dimension used to layout the different data dimensions.
        """
        ...

    @abstractproperty
    def Orientation(self) -> DataPilotFieldOrientationProto:
        """
        specifies where the dimension is used.
        """
        ...

    @abstractproperty
    def Original(self) -> XNamed_a6520b08:
        """
        returns the name of the dimension from which this dimension was cloned, or NULL if it was not cloned.
        """
        ...

    @abstractproperty
    def Position(self) -> int:
        """
        specifies the position of the dimension within its orientation.
        """
        ...

    @abstractproperty
    def UsedHierarchy(self) -> int:
        """
        specifies which hierarchy of the dimension is used.
        """
        ...


__all__ = ['DataPilotSourceDimension']


# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.document
from __future__ import annotations
import typing
import uno
from abc import abstractproperty, ABC
if typing.TYPE_CHECKING:
    from ..beans.named_value import NamedValue as NamedValue_a37a0af3
    from ..frame.x_frame import XFrame as XFrame_7a570956
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from ..io.x_output_stream import XOutputStream as XOutputStream_a4e00b35
    from ..task.x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51
    from ..task.x_status_indicator import XStatusIndicator as XStatusIndicator_e2d00d34

class MediaDescriptor(ABC):
    """
    Service Class

    describes properties of a document, regarding the relationship between the loaded document and the resource the document is loaded from / stored to.
    
    This service may be represented by a com.sun.star.beans.PropertyValue[]. Such descriptors will be passed to different functions, included into possible load/save processes. Every member of such process can use this descriptor and may change it if to actualize the information about the document. So this descriptor should be used as an in/out parameter.
    
    Note:It's not allowed to hold member of this descriptor by references longer than they will be used (especially a possible stream). It's allowed to use it directly or by copying it only.
    
    **since**
    
        LibreOffice 6.4

    See Also:
        `API MediaDescriptor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1document_1_1MediaDescriptor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.document'
    __ooo_full_ns__: str = 'com.sun.star.document.MediaDescriptor'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def EncryptionData(self) -> typing.Tuple[NamedValue_a37a0af3, ...]:
        """
        encryption information for encryption/decryption of documents
        
        It contains the necessary information for encryption/decryption of a component (if necessary). If neither password nor encryption data is specified, loading of a password protected document will fail, storing will be done without encryption. If both are provided, the encryption data is used ( if the filter supports it ).
        
        The encryption data is generated based on the password.
        """
        ...

    @abstractproperty
    def PostData(self) -> uno.ByteSequence:
        """
        contains the data for HTTP post method as a sequence of bytes.
        
        Data to send to a location described by the media descriptor to get a result in return that will be loaded as a component (usually in webforms). Default is: no PostData.
        """
        ...

    @abstractproperty
    def Aborted(self) -> bool:
        """
        May be set by filters or detection services if user has chosen to abort loading/saving, e.g.
        
        while entering a password.
        """
        ...

    @abstractproperty
    def AsTemplate(self) -> bool:
        """
        document is a template
        
        Loading a component of type \"template\" creates a new untitled document by default, but setting the \"AsTemplate\" property to FALSE loads the template document for editing. Setting \"AsTemplate\" to TRUE creates a new untitled document out of the loaded document, even if it has not a \"template\" type.
        """
        ...

    @abstractproperty
    def Author(self) -> str:
        """
        the author of the document
        
        Only for storing versions in components supporting versioning: author of version.
        """
        ...

    @abstractproperty
    def CharacterSet(self) -> str:
        """
        identifier of used character set
        
        Defines the character set for document formats that contain single byte characters (if necessary).
        """
        ...

    @abstractproperty
    def Comment(self) -> str:
        """
        description of document
        
        Only for storing versions in components supporting versioning: comment (description) for stored version.
        """
        ...

    @abstractproperty
    def ComponentData(self) -> object:
        """
        pack specific properties of caller
        
        This is a parameter that can be used for any properties specific for a special component type. Format of that depends from real type of addressed component.
        
        For extensibility, it is recommended to use values of type sequence<com.sun.star.beans.NamedValue> with this property.
        """
        ...

    @abstractproperty
    def DocumentBaseURL(self) -> str:
        """
        The base URL of the document to be used to resolve relative links.
        """
        ...

    @abstractproperty
    def DocumentTitle(self) -> str:
        """
        document title
        
        This parameter can be used to specify a title for a document.
        """
        ...

    @abstractproperty
    def FileName(self) -> str:
        """
        same as MediaDescriptor.URL
        
        It will be supported for compatibility reasons only.
        """
        ...

    @abstractproperty
    def FilterData(self) -> object:
        """
        additional properties for filter
        
        This is a parameter that can be used for any properties specific for a special filter type. It should be used if MediaDescriptor.FilterOptions isn't enough.
        """
        ...

    @abstractproperty
    def FilterFlags(self) -> str:
        """
        same as MediaDescriptor.FilterOptions
        
        It will be supported for compatibility reasons only.
        """
        ...

    @abstractproperty
    def FilterName(self) -> str:
        """
        internal filter name
        
        Name of a filter that should be used for loading or storing the component. Names must match the names of the TypeDetection configuration, invalid names are ignored. If a name is specified on loading, it still will be verified by a filter detection, but in case of doubt it will be preferred.
        
        See this page for a list of internal filter names: https://help.libreoffice.org/latest/en-US/text/shared/guide/convertfilters.html
        """
        ...

    @abstractproperty
    def FilterOptions(self) -> str:
        """
        additional properties for filter
        
        Some filters need additional parameters; use only together with property MediaDescriptor.FilterName. Details must be documented by the filter. This is an old format for some filters. If a string is not enough, filters can use the property MediaDescriptor.FilterData.
        """
        ...

    @abstractproperty
    def Frame(self) -> XFrame_7a570956:
        """
        specifies the frame containing the document.
        
        May be empty.
        """
        ...

    @abstractproperty
    def Hidden(self) -> bool:
        """
        load document invisible
        
        Defines if the loaded component is made visible. If this property is not specified, the component is made visible by default.
        """
        ...

    @abstractproperty
    def HierarchicalDocumentName(self) -> str:
        """
        The hierarchical path to the embedded document from topmost container.
        """
        ...

    @abstractproperty
    def InputStream(self) -> XInputStream_98d40ab4:
        """
        content of document
        
        If used when loading a document: reading must be done using this stream. If no stream is provided, the loader will create a stream by itself using the other properties. It is not allowed to keep a reference to this InputStream after loading the component, and it would be useless, because in general an InputStream is usable for reading only once, except when it also implements the com.sun.star.io.XSeekable interface.
        """
        ...

    @abstractproperty
    def InteractionHandler(self) -> XInteractionHandler_bf80e51:
        """
        handle exceptional situations
        
        Object implementing the com.sun.star.task.InteractionHandler service that is used to handle exceptional situations where proceeding with the task is impossible without additional information or impossible at all. The implemented API provides a default implementation for it that can handle many situations. If no InteractionHandler is set, a suitable exception is thrown. It is not allowed to keep a reference to this object, even not in the loaded or stored component's copy of the MediaDescriptor provided by its arguments attribute.
        """
        ...

    @abstractproperty
    def JumpMark(self) -> str:
        """
        jump to a marked position after loading
        
        This is the same as the text behind a \"#\" in a http URL. But this syntax with a \"#\" is not specified in most URL schemas.
        """
        ...

    @abstractproperty
    def LockContentExtraction(self) -> bool:
        """
        Setting this option will prevent copying/dragging any content anywhere.
        
        The commands 'Copy' and 'Cut' will be disabled; selection clipboard won't work, and dragging with mouse will also be disabled.
        
        **since**
        
            LibreOffice 6.4
        """
        ...

    @abstractproperty
    def LockEditDoc(self) -> bool:
        """
        Setting this option will disable switching to edit mode from read-only mode.
        
        **since**
        
            LibreOffice 6.4
        """
        ...

    @abstractproperty
    def LockExport(self) -> bool:
        """
        Setting this option will prevent exporting document content to any file.
        
        Export, Send, save as, etc will be disabled, as well as individual graphic/chart export and mail merge.
        
        **since**
        
            LibreOffice 6.4
        """
        ...

    @abstractproperty
    def LockPrint(self) -> bool:
        """
        Setting this option will disable all print functions (including Printer setup)
        
        **since**
        
            LibreOffice 6.4
        """
        ...

    @abstractproperty
    def LockSave(self) -> bool:
        """
        Setting this option will disable the save function.
        
        **since**
        
            LibreOffice 6.4
        """
        ...

    @abstractproperty
    def MacroExecutionMode(self) -> int:
        """
        should the macro be executed.
        
        the value should be one from com.sun.star.document.MacroExecMode constant list.
        
        **since**
        
            OOo 1.1.2
        """
        ...

    @abstractproperty
    def MediaType(self) -> str:
        """
        specify mime type of content
        
        Type of the medium to load, that must match to one of the types defined in the TypeDetection configuration (otherwise it's ignored). This bypasses the type detection of the com.sun.star.frame.Desktop environment, so passing a wrong MediaType will cause failure of loading.
        """
        ...

    @abstractproperty
    def OpenFlags(self) -> str:
        """
        please use the corresponding parameters of this descriptor instead
        
        String that summarizes some flags for loading. The string contains capital letters for the flags:
        """
        ...

    @abstractproperty
    def OpenNewView(self) -> bool:
        """
        opens a new view for an already loaded document
        
        Setting this to TRUE forces the component to create a new window on loading in any case. If the component supports multiple views, a second view is opened, if not, the component is loaded one more time. Otherwise the behavior depends on the default window handling of the com.sun.star.frame.Desktop environment.
        """
        ...

    @abstractproperty
    def OutputStream(self) -> XOutputStream_a4e00b35:
        """
        a stream to receive the document data.
        
        If used when storing a document: writing must be done using this stream. If no stream is provided, the loader will create a stream by itself using the other properties. It is not allowed to keep a reference to this OutputStream after storing the component.
        """
        ...

    @abstractproperty
    def Overwrite(self) -> bool:
        """
        overwrite any existing file
        
        For storing only: overwrite any existing file, default is TRUE. Setting this to FALSE raises an error, if the target file already exists.
        """
        ...

    @abstractproperty
    def Password(self) -> str:
        """
        password for loading or storing documents
        
        It contains a password for loading or storing a component (if necessary). If neither password nor encryption data is specified, loading of a password protected document will fail, storing will be done without encryption. If both are provided, the encryption data is used ( if the filter supports it ).
        """
        ...

    @abstractproperty
    def PickListEntry(self) -> bool:
        """
        add loaded document to recent document list
        
        Setting this to FALSE prevents the loaded document to be added to the recent documents list. Default is TRUE.
        
        **since**
        
            LibreOffice 5.1
        """
        ...

    @abstractproperty
    def PostString(self) -> str:
        """
        use MediaDescriptor.PostData instead of this
        
        Same as PostData, but the data is transferred as a string (just for compatibility).
        """
        ...

    @abstractproperty
    def Preview(self) -> bool:
        """
        show preview
        
        Setting this to TRUE tells the a loaded component that it is loaded as a preview, so it can optimize loading and viewing for this special purpose. Default is FALSE.
        """
        ...

    @abstractproperty
    def ReadOnly(self) -> bool:
        """
        open document readonly
        
        Tells whether a document should be loaded in a (logical) readonly or in read/write mode. If opening in the desired mode is impossible, an error occurs. By default the loaded content decides what to do: if its UCB content supports a \"readonly\" property, the logical open mode depends on that, otherwise it will be read/write. This is only a UI related property, opening a document in read only mode will not prevent the component from being modified by API calls, but all modifying functionality in the UI will be disabled or removed.
        """
        ...

    @abstractproperty
    def Referer(self) -> str:
        """
        name of document referrer
        
        A URL describing the environment of the request; e.g. a referrer may be a URL of a document, if a hyperlink inside this document is clicked to load another document. The referrer may be evaluated by the addressed UCB content or the loaded document. Without a referrer the processing of URLs that needs security checks will be denied, e.g. \"macro:\" URLs. Don't be confused about the wrong spelling; it is kept for compatibility reasons.
        """
        ...

    @abstractproperty
    def RepairPackage(self) -> bool:
        """
        let the document be opened in repair mode
        
        For loading of corrupted zip packages: Setting this to TRUE let the document be opened in repair mode, so as much as possible information will be retrieved.
        
        **since**
        
            OOo 1.1.2
        """
        ...

    @abstractproperty
    def Replaceable(self) -> bool:
        """
        Mark the document as replaceable / a placeholder.
        
        Normally a document is always opened in a new frame. If this property is set to true, this document just acts as a placeholder while it's unmodified. I.e. the next opened document from its frame will close and replace it.
        
        This defaults to false, except for the default template of a LibreOffice module, referenced as \"private:factory/&lt;module&gt;\".
        
        **since**
        
            LibreOffice 7.0
        """
        ...

    @abstractproperty
    def StartPresentation(self) -> bool:
        """
        start presentation from a document
        
        Tells the component loading the document that a presentation that is in the document is to be started right away.
        """
        ...

    @abstractproperty
    def StatusIndicator(self) -> XStatusIndicator_e2d00d34:
        """
        can be used for status information
        
        Object implementing the com.sun.star.task.XStatusIndicator interface that can be used to give status information (text or progress) for the task. The office provides a default implementation for it. It is not allowed to keep a reference to this object, even not in the loaded or stored component's copy of the MediaDescriptor provided by its arguments attribute.
        """
        ...

    @abstractproperty
    def SuggestedSaveAsDir(self) -> str:
        """
        allows to specify the URL that is used next time SaveAs dialog is opened
        
        If the parameter is specified, the URL will be used by SaveAs dialog next time as target folder.
        """
        ...

    @abstractproperty
    def SuggestedSaveAsName(self) -> str:
        """
        allows to specify the suggested file name that is used next time SaveAs dialog is opened
        
        If the parameter is specified, the file name will be suggested by SaveAs dialog next time.
        """
        ...

    @abstractproperty
    def TemplateName(self) -> str:
        """
        name of the template instead of the URL
        
        The logical name of a template to load. Together with the MediaDescriptor.TemplateRegion property it can be used instead of the URL of the template. Use always in conjunction with MediaDescriptor.TemplateRegionName.
        """
        ...

    @abstractproperty
    def TemplateRegionName(self) -> str:
        """
        name of the template instead of the URL
        
        See MediaDescriptor.TemplateName. The template region names are the folder names you see in the templates dialog.
        """
        ...

    @abstractproperty
    def URL(self) -> str:
        """
        URL of the document.
        
        The location of the component in URL syntax. It must be a fully qualified URL.
        """
        ...

    @abstractproperty
    def Unpacked(self) -> bool:
        """
        regulate using of compressing
        
        For storing: Setting this to TRUE means, don't use a zip file to save the document, use a folder instead (only usable for UCB contents, that support folders). Default is FALSE.
        """
        ...

    @abstractproperty
    def UpdateDocMode(self) -> int:
        """
        can the document be updated depending from links.
        
        the value should be one from com.sun.star.document.UpdateDocMode constant list.
        
        **since**
        
            OOo 1.1.2
        """
        ...

    @abstractproperty
    def Version(self) -> int:
        """
        storage version
        
        For components supporting versioning: the number of the version to be loaded or saved. Default is zero and means: no version is created or loaded, the \"main\" document is processed.
        """
        ...

    @abstractproperty
    def ViewControllerName(self) -> str:
        """
        specifies the name of the view controller to create when loading a document
        
        If this property is used when loading a document into a frame, then it specifies the name of the view controller to create. That is, the property is passed to the document's com.sun.star.frame.XModel2.createViewController() method.If the loaded document does not support the XModel2 interface, the property is ignored.
        
        **since**
        
            OOo 3.0
        """
        ...

    @abstractproperty
    def ViewData(self) -> object:
        """
        set special view state
        
        Data to set a special view state after loading. The type depends on the component and is usually retrieved from a com.sun.star.frame.Controller object by its com.sun.star.frame.XController interface. Default is: no view data.
        """
        ...

    @abstractproperty
    def ViewId(self) -> int:
        """
        id of the initial view
        
        For components supporting different views: a number to define the view that should be constructed after loading. Default is: zero, and this should be treated by the component as the default view.
        """
        ...


__all__ = ['MediaDescriptor']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
import uno
from enum import IntFlag
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    # document generators will most likely not see this.
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class WindowAttribute(metaclass=UnoConstMeta, type_name="com.sun.star.awt.WindowAttribute", name_space="com.sun.star.awt"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.awt.WindowAttribute``"""
        pass

    class WindowAttributeEnum(IntFlag, metaclass=ConstEnumMeta, type_name="com.sun.star.awt.WindowAttribute", name_space="com.sun.star.awt"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.awt.WindowAttribute`` as Enum values"""
        pass

else:
    if TYPE_CHECKING:
        from com.sun.star.awt import WindowAttribute as WindowAttribute
    else:
        # keep document generators happy
        from ...lo.awt.window_attribute import WindowAttribute as WindowAttribute

    class WindowAttributeEnum(IntFlag):
        """
        Enum of Const Class WindowAttribute

        These values are used to specify the decorations of a window.
        
        IMPORTANT: These constants have to be disjunct with constants in VclWindowPeerAttribute.
        """
        SHOW = WindowAttribute.SHOW
        """
        specifies that the window is initially visible.
        """
        FULLSIZE = WindowAttribute.FULLSIZE
        """
        specifies that the window fills the complete desktop area.
        
        This applies only to top windows.
        """
        OPTIMUMSIZE = WindowAttribute.OPTIMUMSIZE
        """
        specifies that the window is optimum size.
        
        This applies only to top windows.
        """
        MINSIZE = WindowAttribute.MINSIZE
        """
        specifies that the window is minimum size.
        
        This applies only to top windows.
        """
        BORDER = WindowAttribute.BORDER
        """
        specifies that the window has visible borders.
        
        This applies only to top windows.
        """
        SIZEABLE = WindowAttribute.SIZEABLE
        """
        specifies that the size of the window can be changed by the user.
        
        This applies only to top windows.
        """
        MOVEABLE = WindowAttribute.MOVEABLE
        """
        specifies that the window can be moved by the user.
        
        This applies only to top windows.
        """
        CLOSEABLE = WindowAttribute.CLOSEABLE
        """
        specifies that the window can be closed by the user.
        
        This applies only to top windows.
        """
        SYSTEMDEPENDENT = WindowAttribute.SYSTEMDEPENDENT
        """
        specifies that the window should support the com.sun.star.awt.XSystemDependentWindowPeer interface.
        
        This flag may be ignored, but in this case no system-dependent extension works.
        """
        NODECORATION = WindowAttribute.NODECORATION
        """
        specifies that the window should have no decoration.
        """

__all__ = ['WindowAttribute', 'WindowAttributeEnum']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
import typing
from abc import abstractproperty
from .x_draw_view import XDrawView as XDrawView_b0b80b75
from .framework.x_view import XView as XView_ffed0de3
if typing.TYPE_CHECKING:
    from ..container.x_index_access import XIndexAccess as XIndexAccess_f0910d6d
    from ..util.color import Color as Color_68e908c5

class XSlideSorterBase(XDrawView_b0b80b75, XView_ffed0de3):
    """
    This interface exists only because services do not directly support multiple inheritance and attributes.
    
    It provides the interfaces and attributes that every object that implements the SlideSorter service.

    See Also:
        `API XSlideSorterBase <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlideSorterBase.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.XSlideSorterBase'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.drawing.XSlideSorterBase'

    @abstractproperty
    def BackgroundColor(self) -> Color_68e908c5:
        """
        """
        ...

    @abstractproperty
    def DocumentSlides(self) -> XIndexAccess_f0910d6d:
        """
        The set of slides that are displayed by the implementing object.
        
        The default value is the set of all slides of the document for which a slide sorter is created.
        """
        ...

    @abstractproperty
    def HighlightColor(self) -> Color_68e908c5:
        """
        """
        ...

    @abstractproperty
    def IsCenterSelection(self) -> bool:
        """
        When this flag has the value TRUE then every time the current slide is changed the visual area is shifted so that the new current slide is display in the center of the slide sorter window.
        
        It is not always possible to move the current slide into the exact center of the window, for example when slides are located near the start or end of a document.
        
        The default value is FALSE.
        """
        ...

    @abstractproperty
    def IsHighlightCurrentSlide(self) -> bool:
        """
        Set this flag to TRUE in order to have the current slide highlighted.
        
        The default value is FALSE.
        """
        ...

    @abstractproperty
    def IsOrientationVertical(self) -> bool:
        """
        The orientation of a slide sorter can be either vertical (TRUE) or horizontal (FALSE).
        """
        ...

    @abstractproperty
    def IsShowFocus(self) -> bool:
        """
        Set this flag to TRUE to visualize to where the focus is by showing a dotted rectangle around the focused slide.
        
        The default value is TRUE.
        """
        ...

    @abstractproperty
    def IsShowSelection(self) -> bool:
        """
        Set this flag to TRUE in order to visualize the selection of slides (typically a bold frame around the selected slides).
        
        The default value is TRUE.
        """
        ...

    @abstractproperty
    def IsSmoothScrolling(self) -> bool:
        """
        This flag is a hint to make scrolling look smooth.
        """
        ...

    @abstractproperty
    def IsSuspendPreviewUpdatesDuringFullScreenPresentation(self) -> bool:
        """
        This flag controls whether updates of previews are created during full screen presentations (FALSE) or not (TRUE).
        
        The suspension of preview creations is an optimization for not slowing down a running presentation.
        
        The default value is TRUE.
        """
        ...

    @abstractproperty
    def IsUIReadOnly(self) -> bool:
        """
        This flag controls whether the model can be modified by using keyboard or mouse.
        
        The default value is TRUE.
        """
        ...

    @abstractproperty
    def SelectionColor(self) -> Color_68e908c5:
        """
        """
        ...

    @abstractproperty
    def TextColor(self) -> Color_68e908c5:
        """
        """
        ...


__all__ = ['XSlideSorterBase']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..geometry.real_point2_d import RealPoint2D as RealPoint2D_d6e70c78
    from com.sun.star.rendering.FillRule import FillRuleProto  # type: ignore
    from com.sun.star.rendering.FillRule import FillRuleProto  # type: ignore

class XPolyPolygon2D(XInterface_8f010a43):
    """
    Generic interface for poly-polygons in 2D.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XPolyPolygon2D <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XPolyPolygon2D.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.XPolyPolygon2D'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.rendering.XPolyPolygon2D'

    @abstractmethod
    def addPolyPolygon(self, position: RealPoint2D_d6e70c78, polyPolygon: XPolyPolygon2D) -> None:
        """
        Add the specified poly-polygon at the given position.
        
        One can do symbolic path construction with this method. The poly-polygons added by this method are not joined in the sense that they participate in mutual fill rule calculations like the polygons inside a single poly-polygon do. When rendering such a poly-polygon without transparency, it will look like the constituting poly-polygons rendered separately on top of another. Alas, when rendering with transparency, separate rendering will combine the alpha of overlapping areas, whereas addPolyPolygon results in constant alpha, regardless how many internal poly-polygons overlap at a single place.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def getFillRule(self) -> FillRuleProto:
        """
        Query the rule used to determine inside and outside of the poly-polygon.
        """
        ...
    @abstractmethod
    def getNumberOfPolygonPoints(self, polygon: int) -> int:
        """
        Query number of points inside given polygon.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def getNumberOfPolygons(self) -> int:
        """
        Query number of polygons inside this poly-polygon.
        """
        ...
    @abstractmethod
    def isClosed(self, index: int) -> bool:
        """
        Query whether the specified polygon outline is closed.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def setClosed(self, index: int, closedState: bool) -> None:
        """
        Set the close state of the specified polygon outline.
        
        Use -1 as the index to affect all polygons of this poly-polygon.

        Raises:
            com.sun.star.lang.IndexOutOfBoundsException: ``IndexOutOfBoundsException``
        """
        ...
    @abstractmethod
    def setFillRule(self, fillRule: FillRuleProto) -> None:
        """
        Set the rule used to determine inside and outside of the poly-polygon.
        """
        ...

__all__ = ['XPolyPolygon2D']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sdb


class ErrorCondition(object):
    """
    Const Class

    defines error conditions for OpenOffice.org Base core components
    
    Core components of OpenOffice.org will use those error conditions as error codes (com.sun.star.sdbc.SQLException.ErrorCode) wherever possible.That is, if an SQLException is raised by such a component, caused by an error condition which is included in the ErrorCondition group, then the respective negative value will be used as ErrorCode.
    
    This allows to determine specific error conditions in your client code, and to handle it appropriately.
    
    Note that before you examine the ErrorCode member of a caught SQLException, you need to make sure that the exception is really thrown by an OpenOffice.org Base core component. To do so, check whether the error message (Exception.Message) starts with the vendor string [OOoBase].
    
    The list of defined error conditions, by nature, is expected to permanently grow, so never assume it being finalized.

    See Also:
        `API ErrorCondition <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1sdb_1_1ErrorCondition.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sdb'
    __ooo_full_ns__: str = 'com.sun.star.sdb.ErrorCondition'
    __ooo_type_name__: str = 'const'

    ROW_SET_OPERATION_VETOED = 100
    """
    is used by and RowSet to indicate that an operation has been vetoed by one of its approval listeners
    
    This error condition results in raising a RowSetVetoException.
    """
    PARSER_CYCLIC_SUB_QUERIES = 200
    """
    indicates that while parsing an SQL statement, cyclic sub queries have been detected.
    
    Imagine you have a client-side query SELECT * FROM table, which is saved as \"query1\". Additionally, there is a query \"query2\" defined as SELECT * FROM query1. Now if you try to change the statement of query1 to SELECT * FROM query2, this is prohibited, because it would lead to a cyclic sub query.
    """
    DB_OBJECT_NAME_WITH_SLASHES = 300
    """
    indicates that the name of a client side database object - a query, a form, or a report - contains one or more slashes, which is forbidden.
    """
    DB_INVALID_SQL_NAME = 301
    """
    indicates that an identifier is not SQL conform.
    """
    DB_QUERY_NAME_WITH_QUOTES = 302
    """
    indicates that the name of a query contains quote characters.
    
    This error condition is met when the user attempts to save a query with a name which contains one of the possible database quote characters. This is an error since query names can potentially be used in SELECT statements, where quote identifiers would render the statement invalid.
    """
    DB_OBJECT_NAME_IS_USED = 303
    """
    indicates that an attempt was made to save a database object under a name which is already used in the database.
    
    In databases which support query names to appear in SELECT statements, this could mean that a table was attempted to be saved with the name of an existing query, or vice versa.
    
    Otherwise, it means an object was attempted to be saved with the name of an already existing object of the same type.
    """
    DB_NOT_CONNECTED = 304
    """
    indicates an operation was attempted which needs a connection to the database, which did not exist at that time.
    """
    AB_ADDRESSBOOK_NOT_FOUND = 500
    """
    used by the component implementing address book access to indicate that a requested address book could not be accessed.
    
    For instance, this error code is used when you try to access the address book in a Thunderbird profile named MyProfile, but there does not exist a profile with this name.
    """
    DATA_CANNOT_SELECT_UNFILTERED = 550
    """
    used to indicate that a SELECT operation on a table needs a filter.
    
    Some database drivers are not able to SELECT from a table if the statement does not contain a WHERE clause. In this case, a statement like SELECT * FROM \"table\" will fail with the error code DATA_CANNOT_SELECT_UNFILTERED.
    
    It is also legitimate for the driver to report this error condition as warning, and provide an empty result set, instead of ungraceful failing.
    """

__all__ = ['ErrorCondition']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing
from .homogen_matrix_line4 import HomogenMatrixLine4 as HomogenMatrixLine4_2b170ef2


class HomogenMatrix4(object):
    """
    Struct Class

    specifies a homogeneous matrix by four homogeneous lines.

    See Also:
        `API HomogenMatrix4 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1drawing_1_1HomogenMatrix4.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.HomogenMatrix4'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.drawing.HomogenMatrix4'
    """Literal Constant ``com.sun.star.drawing.HomogenMatrix4``"""

    def __init__(self, Line1: typing.Optional[HomogenMatrixLine4_2b170ef2] = UNO_NONE, Line2: typing.Optional[HomogenMatrixLine4_2b170ef2] = UNO_NONE, Line3: typing.Optional[HomogenMatrixLine4_2b170ef2] = UNO_NONE, Line4: typing.Optional[HomogenMatrixLine4_2b170ef2] = UNO_NONE) -> None:
        """
        Constructor

        Arguments:
            Line1 (HomogenMatrixLine4, optional): Line1 value.
            Line2 (HomogenMatrixLine4, optional): Line2 value.
            Line3 (HomogenMatrixLine4, optional): Line3 value.
            Line4 (HomogenMatrixLine4, optional): Line4 value.
        """
        super().__init__()

        if isinstance(Line1, HomogenMatrix4):
            oth: HomogenMatrix4 = Line1
            self.Line1 = oth.Line1
            self.Line2 = oth.Line2
            self.Line3 = oth.Line3
            self.Line4 = oth.Line4
            return

        kargs = {
            "Line1": Line1,
            "Line2": Line2,
            "Line3": Line3,
            "Line4": Line4,
        }
        if kargs["Line1"] is UNO_NONE:
            kargs["Line1"] = None
        if kargs["Line2"] is UNO_NONE:
            kargs["Line2"] = None
        if kargs["Line3"] is UNO_NONE:
            kargs["Line3"] = None
        if kargs["Line4"] is UNO_NONE:
            kargs["Line4"] = None
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._line1 = kwargs["Line1"]
        self._line2 = kwargs["Line2"]
        self._line3 = kwargs["Line3"]
        self._line4 = kwargs["Line4"]


    @property
    def Line1(self) -> HomogenMatrixLine4_2b170ef2:
        return self._line1

    @Line1.setter
    def Line1(self, value: HomogenMatrixLine4_2b170ef2) -> None:
        self._line1 = value

    @property
    def Line2(self) -> HomogenMatrixLine4_2b170ef2:
        return self._line2

    @Line2.setter
    def Line2(self, value: HomogenMatrixLine4_2b170ef2) -> None:
        self._line2 = value

    @property
    def Line3(self) -> HomogenMatrixLine4_2b170ef2:
        return self._line3

    @Line3.setter
    def Line3(self, value: HomogenMatrixLine4_2b170ef2) -> None:
        self._line3 = value

    @property
    def Line4(self) -> HomogenMatrixLine4_2b170ef2:
        return self._line4

    @Line4.setter
    def Line4(self, value: HomogenMatrixLine4_2b170ef2) -> None:
        self._line4 = value


__all__ = ['HomogenMatrix4']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class HomogenMatrixLine4(object):
    """
    Struct Class

    specifies a single line for a HomogenMatrix4.

    See Also:
        `API HomogenMatrixLine4 <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1drawing_1_1HomogenMatrixLine4.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.HomogenMatrixLine4'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.drawing.HomogenMatrixLine4'
    """Literal Constant ``com.sun.star.drawing.HomogenMatrixLine4``"""

    def __init__(self, Column1: typing.Optional[float] = 0.0, Column2: typing.Optional[float] = 0.0, Column3: typing.Optional[float] = 0.0, Column4: typing.Optional[float] = 0.0) -> None:
        """
        Constructor

        Arguments:
            Column1 (float, optional): Column1 value.
            Column2 (float, optional): Column2 value.
            Column3 (float, optional): Column3 value.
            Column4 (float, optional): Column4 value.
        """
        super().__init__()

        if isinstance(Column1, HomogenMatrixLine4):
            oth: HomogenMatrixLine4 = Column1
            self.Column1 = oth.Column1
            self.Column2 = oth.Column2
            self.Column3 = oth.Column3
            self.Column4 = oth.Column4
            return

        kargs = {
            "Column1": Column1,
            "Column2": Column2,
            "Column3": Column3,
            "Column4": Column4,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._column1 = kwargs["Column1"]
        self._column2 = kwargs["Column2"]
        self._column3 = kwargs["Column3"]
        self._column4 = kwargs["Column4"]


    @property
    def Column1(self) -> float:
        return self._column1

    @Column1.setter
    def Column1(self, value: float) -> None:
        self._column1 = value

    @property
    def Column2(self) -> float:
        return self._column2

    @Column2.setter
    def Column2(self, value: float) -> None:
        self._column2 = value

    @property
    def Column3(self) -> float:
        return self._column3

    @Column3.setter
    def Column3(self, value: float) -> None:
        self._column3 = value

    @property
    def Column4(self) -> float:
        return self._column4

    @Column4.setter
    def Column4(self, value: float) -> None:
        self._column4 = value


__all__ = ['HomogenMatrixLine4']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n


class TextConversionOption(object):
    """
    Const Class

    Text conversion options to be used with XTextConversion.
    
    These text conversion options are usually selected by end users. The options can be combined and may be related to TextConversionType.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API TextConversionOption <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1TextConversionOption.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.TextConversionOption'
    __ooo_type_name__: str = 'const'

    NONE = 0
    """
    No option.
    """
    CHARACTER_BY_CHARACTER = 1
    """
    Character by character conversion.
    """
    IGNORE_POST_POSITIONAL_WORD = 2
    """
    Ignore post-positional word for Hangul to Hanja conversion.
    """
    USE_CHARACTER_VARIANTS = 2
    """
    Use Taiwan, HongKong SAR, and Macao SAR character variants for Simplified to Traditional Chinese conversion.
    
    **since**
    
        OOo 2.0
    """

__all__ = ['TextConversionOption']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.chart
# Libre Office Version: 7.4
from __future__ import annotations
from enum import Enum


class ChartLegendPosition(Enum):
    """
    Enum Class


    See Also:
        `API ChartLegendPosition <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1chart.html#a65c2b55fdf73cbbf2fdcfef7d305b6c3>`_
    """
    __ooo_ns__: str = "com.sun.star.chart"
    __ooo_full_ns__: str = "com.sun.star.chart.ChartLegendPosition"
    __ooo_type_name__: str = "enum"

    @property
    def typeName(self) -> str:
        return "com.sun.star.chart.ChartLegendPosition"

    BOTTOM = "BOTTOM"
    """
    displays the chart legend beneath the diagram.
    """
    LEFT = "LEFT"
    """
    displays the chart legend on the left side of the diagram.
    """
    NONE = "NONE"
    """
    error indicators are not displayed.
    
    displays no regression curve.
    
    no chart legend is displayed.
    
    displays no error indicators.
    """
    RIGHT = "RIGHT"
    """
    displays the chart legend on the right side of the diagram.
    """
    TOP = "TOP"
    """
    displays the chart legend above the diagram.
    """

__all__ = ["ChartLegendPosition"]




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.drawing
from __future__ import annotations
import typing
from abc import abstractproperty
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..beans.x_tolerant_multi_property_set import XTolerantMultiPropertySet as XTolerantMultiPropertySet_7bd4114e
from .x_glue_points_supplier import XGluePointsSupplier as XGluePointsSupplier_3a770faa
from .x_shape import XShape as XShape_8fd00a3d
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
    from .homogen_matrix3 import HomogenMatrix3 as HomogenMatrix3_f0fb0d69
    from ..style.x_style import XStyle as XStyle_7c7f09a2

class Shape(XPropertySet_bc180bfa, XTolerantMultiPropertySet_7bd4114e, XGluePointsSupplier_3a770faa, XShape_8fd00a3d, XComponent_98dc0ab5):
    """
    Service Class

    This abstract service specifies the general characteristics of all Shapes.
    
    **since**
    
        LibreOffice 4.2

    See Also:
        `API Shape <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1drawing_1_1Shape.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.drawing'
    __ooo_full_ns__: str = 'com.sun.star.drawing.Shape'
    __ooo_type_name__: str = 'service'

    @abstractproperty
    def InteropGrabBag(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        """
        Grab bag of shape properties, used as a string-any map for interim interop purposes.
        
        This property is intentionally not handled by the ODF filter. Any member that should be handled there should be first moved out from this grab bag to a separate property.
        
        **since**
        
            LibreOffice 4.2
        """
        ...

    @abstractproperty
    def Hyperlink(self) -> str:
        """
        this property lets you get and set a hyperlink for this shape.
        """
        ...

    @abstractproperty
    def LayerID(self) -> int:
        """
        This is the ID of the Layer to which this Shape is attached.
        """
        ...

    @abstractproperty
    def LayerName(self) -> str:
        """
        This is the name of the Layer to which this Shape is attached.
        """
        ...

    @abstractproperty
    def MoveProtect(self) -> bool:
        """
        With this set to TRUE, this Shape cannot be moved interactively in the user interface.
        """
        ...

    @abstractproperty
    def Name(self) -> str:
        """
        This is the name of this Shape.
        """
        ...

    @abstractproperty
    def NavigationOrder(self) -> int:
        """
        this property stores the navigation order of this shape.
        
        If this value is negative, the navigation order for this shapes page is equal to the z-order.
        """
        ...

    @abstractproperty
    def Printable(self) -> bool:
        """
        If this is FALSE, the Shape is not visible on printer outputs.
        """
        ...

    @abstractproperty
    def RelativeHeight(self) -> int:
        """
        contains the relative height of the object.
        
        It is only valid if it is greater than zero.
        
        **since**
        
            LibreOffice 4.3
        """
        ...

    @abstractproperty
    def RelativeHeightRelation(self) -> int:
        """
        contains the relation of the relative height of the object.
        
        It is only valid if RelativeHeight is greater than zero.
        
        **since**
        
            LibreOffice 4.3
        """
        ...

    @abstractproperty
    def RelativeWidth(self) -> int:
        """
        contains the relative width of the object.
        
        It is only valid if it is greater than zero.
        
        **since**
        
            LibreOffice 4.3
        """
        ...

    @abstractproperty
    def RelativeWidthRelation(self) -> int:
        """
        contains the relation of the relative width of the object.
        
        It is only valid if RelativeWidth is greater than zero.
        
        **since**
        
            LibreOffice 4.3
        """
        ...

    @abstractproperty
    def ShapeUserDefinedAttributes(self) -> XNameContainer_cb90e47:
        """
        this property stores xml attributes.
        
        They will be saved to and restored from automatic styles inside xml files.
        """
        ...

    @abstractproperty
    def SizeProtect(self) -> bool:
        """
        With this set to TRUE, this Shape may not be sized interactively in the user interface.
        """
        ...

    @abstractproperty
    def Style(self) -> XStyle_7c7f09a2:
        """
        this property lets you get and set a style for this shape.
        """
        ...

    @abstractproperty
    def Transformation(self) -> HomogenMatrix3_f0fb0d69:
        """
        this property lets you get and set the transformation matrix for this shape.
        
        The transformation is a 3x3 homogeneous matrix and can contain translation, rotation, shearing and scaling.
        """
        ...

    @abstractproperty
    def Visible(self) -> bool:
        """
        If this is FALSE, the Shape is not visible on screen outputs.
        
        Please note that the Shape may still be visible when printed, see Printable.
        """
        ...

    @abstractproperty
    def ZOrder(self) -> int:
        """
        is used to query or change the ZOrder of this Shape.
        """
        ...


__all__ = ['Shape']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.sheet
# Libre Office Version: 7.4
from ooo.oenv.env_const import UNO_NONE
import typing


class DataPilotFieldFilter(object):
    """
    Struct Class


    See Also:
        `API DataPilotFieldFilter <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1sheet_1_1DataPilotFieldFilter.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.DataPilotFieldFilter'
    __ooo_type_name__: str = 'struct'
    typeName: str = 'com.sun.star.sheet.DataPilotFieldFilter'
    """Literal Constant ``com.sun.star.sheet.DataPilotFieldFilter``"""

    def __init__(self, FieldName: typing.Optional[str] = '', MatchValueName: typing.Optional[str] = '', MatchValue: typing.Optional[str] = '') -> None:
        """
        Constructor

        Arguments:
            FieldName (str, optional): FieldName value.
            MatchValueName (str, optional): MatchValueName value.
            MatchValue (str, optional): MatchValue value.
        """
        super().__init__()

        if isinstance(FieldName, DataPilotFieldFilter):
            oth: DataPilotFieldFilter = FieldName
            self.FieldName = oth.FieldName
            self.MatchValueName = oth.MatchValueName
            self.MatchValue = oth.MatchValue
            return

        kargs = {
            "FieldName": FieldName,
            "MatchValueName": MatchValueName,
            "MatchValue": MatchValue,
        }
        self._init(**kargs)

    def _init(self, **kwargs) -> None:
        self._field_name = kwargs["FieldName"]
        self._match_value_name = kwargs["MatchValueName"]
        self._match_value = kwargs["MatchValue"]


    @property
    def FieldName(self) -> str:
        """
        Field name.
        """
        return self._field_name

    @FieldName.setter
    def FieldName(self, value: str) -> None:
        self._field_name = value

    @property
    def MatchValueName(self) -> str:
        """
        String value that needs to match against, locale dependent.
        
        This is the value as name/label as also displayed in the filter popup dialog, maybe formatted by user applied number formats.
        """
        return self._match_value_name

    @MatchValueName.setter
    def MatchValueName(self, value: str) -> None:
        self._match_value_name = value

    @property
    def MatchValue(self) -> str:
        """
        String value that needs to match against, locale independent.
        
        This is the underlying value formatted in a standardized way, for example ISO 8601 YYYY-MM-DD for dates.
        """
        return self._match_value

    @MatchValue.setter
    def MatchValue(self, value: str) -> None:
        self._match_value = value


__all__ = ['DataPilotFieldFilter']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2
from __future__ import annotations
import typing
from abc import abstractmethod
from .x_supported_locales import XSupportedLocales as XSupportedLocales_5bda1056
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
    from ..lang.locale import Locale as Locale_70d308fa
    from .proofreading_result import ProofreadingResult as ProofreadingResult_6cc910d4

class XProofreader(XSupportedLocales_5bda1056):
    """
    API for proofreading a text.
    
    **since**
    
        OOo 3.0.1

    See Also:
        `API XProofreader <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XProofreader.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.XProofreader'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.linguistic2.XProofreader'

    @abstractmethod
    def doProofreading(self, aDocumentIdentifier: str, aText: str, aLocale: Locale_70d308fa, nStartOfSentencePosition: int, nSuggestedBehindEndOfSentencePosition: int, aProperties: typing.Tuple[PropertyValue_c9610c73, ...]) -> ProofreadingResult_6cc910d4:
        """
        start checking
        
        Currently the following properties may be supported:

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def ignoreRule(self, aRuleIdentifier: str, aLocale: Locale_70d308fa) -> None:
        """
        disables a specific rule for a given locale.
        
        If the locale is empty the rule should be ignored for all languages.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def isSpellChecker(self) -> bool:
        """
        whether is the text checked by the spell checker
        """
        ...
    @abstractmethod
    def resetIgnoreRules(self) -> None:
        """
        sets all rules back to their default settings.
        """
        ...

__all__ = ['XProofreader']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.i18n
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .native_number_xml_attributes import NativeNumberXmlAttributes as NativeNumberXmlAttributes_5e4f1070
    from ..lang.locale import Locale as Locale_70d308fa

class XNativeNumberSupplier(XInterface_8f010a43):
    """
    Methods to convert between strings of ASCII Arabic digits and native numeral strings.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XNativeNumberSupplier <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1i18n_1_1XNativeNumberSupplier.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.i18n'
    __ooo_full_ns__: str = 'com.sun.star.i18n.XNativeNumberSupplier'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.i18n.XNativeNumberSupplier'

    @abstractmethod
    def convertFromXmlAttributes(self, aAttr: NativeNumberXmlAttributes_5e4f1070) -> int:
        """
        Convert XML attributes to a NatNum value.
        """
        ...
    @abstractmethod
    def convertToXmlAttributes(self, aLocale: Locale_70d308fa, nNativeNumberMode: int) -> NativeNumberXmlAttributes_5e4f1070:
        """
        Convert a specific NatNum/Locale combination to attributes used in the XML file format.
        """
        ...
    @abstractmethod
    def getNativeNumberString(self, aNumberString: str, aLocale: Locale_70d308fa, nNativeNumberMode: int) -> str:
        """
        Returns native number string for given number string.
        """
        ...
    @abstractmethod
    def isValidNatNum(self, aLocale: Locale_70d308fa, nNativeNumberMode: int) -> bool:
        """
        Check if the NatNum is valid for the given locale.
        """
        ...

__all__ = ['XNativeNumberSupplier']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.datatransfer.clipboard
from __future__ import annotations
import typing
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..x_transferable import XTransferable as XTransferable_2d800f38
    from .x_clipboard_owner import XClipboardOwner as XClipboardOwner_8713d8

class XClipboard(XInterface_8f010a43):
    """

    See Also:
        `API XClipboard <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1datatransfer_1_1clipboard_1_1XClipboard.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.datatransfer.clipboard'
    __ooo_full_ns__: str = 'com.sun.star.datatransfer.clipboard.XClipboard'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.datatransfer.clipboard.XClipboard'

    @abstractmethod
    def getContents(self) -> XTransferable_2d800f38:
        """
        To get the current content of the clipboard.
        """
        ...
    @abstractmethod
    def getName(self) -> str:
        """
        To get the name of the clipboard instance.
        
        If the returned string is empty the clipboard instance is the system clipboard.
        """
        ...
    @abstractmethod
    def setContents(self, xTrans: XTransferable_2d800f38, xClipboardOwner: XClipboardOwner_8713d8) -> None:
        """
        Sets the current contents of the clipboard to the specified transferable object and registers the specified clipboard owner as the owner of the new contents.
        
        If the given com.sun.star.datatransfer.XTransferable has no com.sun.star.datatransfer.DataFlavor the clipboard will be deleted.
        
        A NULL value is not allowed.
        
        NULL is an acceptable value and means that the caller is not interested in lost ownership notifications.
        """
        ...

__all__ = ['XClipboard']





# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.ucb
from __future__ import annotations
from .x_content_provider import XContentProvider as XContentProvider_d4150cc0

class HelpContentProvider(XContentProvider_d4150cc0):
    """
    Service Class

    The Help Content Provider (HCP) implements a ContentProvider for the UniversalContentBroker (UCB).
    
    The served contents enable access to the help contents and to the search engine.

    See Also:
        `API HelpContentProvider <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1ucb_1_1HelpContentProvider.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.ucb'
    __ooo_full_ns__: str = 'com.sun.star.ucb.HelpContentProvider'
    __ooo_type_name__: str = 'service'


__all__ = ['HelpContentProvider']




# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.rendering


class PathJoinType(object):
    """
    Const Class

    Determines which shape to use when joining path segments.
    
    The joins between different paths segments can be formed out of several different shapes (which are of course only visible for strokes wider than one device pixel).
    
    **since**
    
        OOo 2.0

    See Also:
        `API PathJoinType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1rendering_1_1PathJoinType.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.rendering'
    __ooo_full_ns__: str = 'com.sun.star.rendering.PathJoinType'
    __ooo_type_name__: str = 'const'

    NONE = 0
    """
    Do not join the path segments at all.
    
    This join type might lead, depending on the angle between the segments, to visible cracks at the meeting points.
    """
    MITER = 1
    """
    Join the path segment by extending the outer border until they intersect.
    """
    ROUND = 2
    """
    Join the path segment with a pie-like patch, such that the outer line of the meeting point is round.
    """
    BEVEL = 3
    """
    Join the path segment by connecting the outer ends of the abutting segments with a straight line.
    """

__all__ = ['PathJoinType']



# coding: utf-8
#
# Copyright 2023 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.linguistic2
from __future__ import annotations
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
    from ..lang.locale import Locale as Locale_70d308fa
    from .x_conversion_dictionary import XConversionDictionary as XConversionDictionary_a04e1209
    from com.sun.star.linguistic2.ConversionDirection import ConversionDirectionProto  # type: ignore
    from com.sun.star.linguistic2.ConversionDirection import ConversionDirectionProto  # type: ignore

class XConversionDictionaryList(XInterface_8f010a43):
    """
    is used to manage and maintain a list of conversion dictionaries.
    
    The dictionaries added to the list may or may not support the com.sun.star.util.XFlushable interface. If they do those dictionaries have to be flushed upon termination of the dictionary list.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API XConversionDictionaryList <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1linguistic2_1_1XConversionDictionaryList.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.linguistic2'
    __ooo_full_ns__: str = 'com.sun.star.linguistic2.XConversionDictionaryList'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.linguistic2.XConversionDictionaryList'

    @abstractmethod
    def addNewDictionary(self, aName: str, aLocale: Locale_70d308fa, nConversionDictionaryType: int) -> XConversionDictionary_a04e1209:
        """
        creates a new dictionary and adds it to the dictionary list.
        
        The dictionary will be empty and active.

        Raises:
            com.sun.star.lang.NoSupportException: ``NoSupportException``
            com.sun.star.container.ElementExistException: ``ElementExistException``
        """
        ...
    @abstractmethod
    def getDictionaryContainer(self) -> XNameContainer_cb90e47:
        """
        The interface can be used to add, remove or retrieve dictionaries from the list by specifying the name of the dictionary, and (in case of inserting) the interface to the dictionary as second parameter.
        
        A dictionary to be added must support the com.sun.star.linguistic2.XConversionDictionary interface. The dictionary to be added needs not necessarily be created by this service.
        
        The com.sun.star.container.XNameReplace.replaceByName function is implemented empty since renaming of dictionaries is not allowed.
        """
        ...
    @abstractmethod
    def queryConversions(self, aText: str, nStartPos: int, nLength: int, aLocale: Locale_70d308fa, nConversionDictionaryType: int, eDirection: ConversionDirectionProto, nTextConversionOptions: int) -> typing.Tuple[str, ...]:
        """
        searches for entries that match the given text.
        
        All active dictionaries with matching locales and conversion type will be searched for entries matching the given text.
        
        The exact string to be looked for is the substring from the aText parameter that starts at position nStartPos and has the length nLength.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.lang.NoSupportException: ``NoSupportException``
        """
        ...
    @abstractmethod
    def queryMaxCharCount(self, aLocale: Locale_70d308fa, nConversionDictionaryType: int, eDirection: ConversionDirectionProto) -> int:
        """
        returns the maximum number of characters used as left or right text in entries.
        
        All active dictionaries of the specified locale and type will be looked up to get the result.
        
        The parameter eDirection specifies if only the left text or the right text from entries should be considered.
        """
        ...

__all__ = ['XConversionDictionaryList']
